;;; -*- Mode: Lisp; Package: FORM -*-
(in-package "FORM")  ;; creates package for abstract syntax. 

(in-package "FORM")  ;; enters package for generated code.  

(use-package '("NEWATTR" "LANG" "SB-RUNTIME" "SORT" "TERM" "OCC" "OPER" "ERGOLISP"))


(export '( FORM-UNPARSE  FORM-WIN-UNPARSE ))

(DEFVAR FORM-BRACKET-INFO (MAKE-HASH-TABLE :TEST #'EQ)) 
(CLRHASH FORM-BRACKET-INFO) 
(MAPC
 #'(LAMBDA (ENTRY)
     (SET-BRACKET-INFO (CAR ENTRY) (CADR ENTRY) (CADDR ENTRY) FORM-BRACKET-INFO))
 '((EXP SBST::|(| SBST::|)|))) 

(DEFVAR FORM-PREC-INFO (MAKE-HASH-TABLE :TEST #'EQ)) 
(CLRHASH FORM-PREC-INFO) 
(MAPC #'(LAMBDA (NT)
          (INIT-PREC-INFO NT FORM-PREC-INFO)) '(EXP)) 
(MAPC
 #'(LAMBDA (ENTRY)
     (SET-PREC-INFO (CAR ENTRY) (CADR ENTRY) (CADDR ENTRY) (CADDDR ENTRY)
                    FORM-PREC-INFO))
 '((EXP JUX 1 40) (EXP SBST::@ 1 30) (EXP SBST::* 1 20) (EXP SBST::+ 1 10)
  (EXP JUX 2 41) (EXP SBST::@ 2 31) (EXP SBST::* 2 21) (EXP SBST::+ 2 11))) 

(DEFVAR FORM-SPACING-INFO (MAKE-HASH-TABLE :TEST #'EQ)) 
(CLRHASH FORM-SPACING-INFO) 
(MAPC
 #'(LAMBDA (T1
            T2
            BP)
     (COND ((ASSOC T2 (GETHASH T1 FORM-SPACING-INFO)))
           (T
            (SETF (GETHASH T1 FORM-SPACING-INFO)
                  (CONS (LIST T2 BP) (GETHASH T1 FORM-SPACING-INFO))))))
 '(SBST::NUMBER SBST::|(| SBST::|(| SBST::|)| SBST::^ SBST::* SBST::- SBST::+
  SBST::= SBST::[ SBST::] SBST::< SBST::> SBST::<= SBST::>= SBST::<> SBST::|:=|
  SBST::|;| SBST::|:| SBST::|,| SBST::!! SBST::! SBST::@ SBST::ID SBST::NUMBER
  SBST::STRING EXP SBST::@ EXP)
 '(SBST::STRING :ARB SBST::|)| SBST::|)| SBST::|)| SBST::|)| SBST::|)|
  SBST::|)| SBST::|)| SBST::|)| SBST::|)| SBST::|)| SBST::|)| SBST::|)|
  SBST::|)| SBST::|)| SBST::|)| SBST::|)| SBST::|)| SBST::|)| SBST::|)|
  SBST::|)| SBST::|)| SBST::|)| SBST::|)| SBST::|)| SBST::|)| EXP SBST::@)
 '(1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0)) 

(DEFVAR FORM-KEY-TOKEN-MAP (MAKE-HASH-TABLE :TEST #'EQ)) 
(DEFVAR FORM-KEY-ESC-TOKEN-MAP (IF FORM-ESCAPE-CHAR (MAKE-HASH-TABLE :TEST #'EQ))) 
(DEFVAR FORM-LT-TOKEN-MAP (MAKE-HASH-TABLE :TEST #'EQUAL)) 
(DEFVAR FORM-LT-ESC-TOKEN-MAP (IF FORM-ESCAPE-CHAR (MAKE-HASH-TABLE :TEST #'EQUAL))) 


(DEFUN FORM::FORM-UNPARSE (NT AS &KEY (STYLE *UNPARSE-STYLE*))
  (LET* ((*UNPARSER-OP-LIST* FORM-ALL-OPERATORS-LIST)
         (*KEY-TOKEN-MAP* FORM-KEY-TOKEN-MAP)
         (*KEY-ESC-TOKEN-MAP* FORM-KEY-ESC-TOKEN-MAP)
         (*LT-TOKEN-MAP* FORM-LT-TOKEN-MAP)
         (*LT-ESC-TOKEN-MAP* FORM-LT-ESC-TOKEN-MAP)
         (*APPLY-LT-DIS-FUN* #'APPLY-LEXICAL-TERMINAL-DISCRIMINATOR)
         (*APPLY-LT-DES-FUN* #'APPLY-LEXICAL-TERMINAL-DESTRUCTOR)
         (*APPLY-LT-TOKEN-CONS-FUN* #'APPLY-LT-TOKEN-CONSTRUCTOR)
         (*BRACKET-INFO* FORM-BRACKET-INFO)
         (*PREC-INFO* FORM-PREC-INFO)
         (SORT (OPSIG-OUTPUT (OPSIG-TABLE-LOOKUP (TERM-OP AS))))
         (NT-NAME
          (COND (NT)
                ((IS-SORT-TTYPE SORT)
                 (DS-SORT-TTYPE SORT))
                (T
                 'EXP)))
         (*CASE-SENSITIVE* FORM-CASE-SENSITIVE)
         (*ESCAPE-CHARACTER* FORM-ESCAPE-CHAR)
         (*RESTRICTED-CHARS* FORM-RESTRICTED-CHARS)
         (*STRING-CHAR* FORM-STRING-CHAR)
         (*LITERAL-CHAR* FORM-LITERAL-CHAR)
         (*KEYWORD-CHAR* FORM-KEYWORD-CHAR)
         (*UNPARSE-STYLE*
          (IF (AND STYLE (NOT (CONSP STYLE))) (LIST STYLE) STYLE))
         (*NO-ESCAPES* (OR *NO-ESCAPES* (NULL (INSERT-ESCAPES?))))
         (*CURRENT-PRINT-DEPTH* 1))
    (LET ((UTERM
           (CASE NT-NAME
             (EXP (FORM-UNP-EXP AS :TOP-LEVEL? T))
             (T (UNPARSE-RUNTIME-ERROR :NT-NOT-UNPARSABLE NT-NAME) NIL))))
      UTERM))) 

(DEFUN FORM::FORM-WIN-UNPARSE (UTERM WIDTH &KEY (FONTWIDTH SB-DEFFONTWIDTH) (FONTHEIGHT SB-DEFFONTHEIGHT))
  (LET* ((*CASE-SENSITIVE* FORM-CASE-SENSITIVE)
         (*UNPARSER-OP-LIST* FORM-ALL-OPERATORS-LIST)
         (*SPACING-INFO* FORM-SPACING-INFO))
    (FORMAT-UTERM UTERM WIDTH :FONTWIDTH FONTWIDTH :FONTHEIGHT FONTHEIGHT))) 



(DEFUN FORM-UNP-EXP (AS &KEY (TOP-LEVEL? NIL))
  (MEMO-UTERM AS #'FORM-UNP-EXP-AUX :TOP-LEVEL? TOP-LEVEL?)) 



(DEFUN FORM-UNP-EXP-AUX (AS)
  (LET (V0
        V1
        V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4 V5 V6 V7)
    (SETF V0 AS)
    (NT-UNP 'EXP AS
            ((UNP-BIND 'ALT_ V0)
             (DIS-ALT V0
                      ((LAMBDA (X)
                         (DIS-LT 'SBST::ID X))
                       (LAMBDA (X)
                         (DIS-LT 'SBST::NUMBER X))
                       (LAMBDA (X)
                         (AND (DIS-OP 'FORM::TUPLE X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'FUNCALL X)
                              (AND (DIS-OP 'FORM::ARGS (TERM-ARGN X 1)))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'FORM::APPL X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'FORM::PLUS X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'FORM::MULT X)))
                       (LAMBDA (X)
                         (AND (DIS-OP 'FORM::ATSIGN X)))
                       (LAMBDA (X)
                         (OR (AND (DIS-OP 'IF X))
                             (AND (DIS-OP 'FORM::IF-ELSE X))))
                       (LAMBDA (X)
                         (AND (DIS-OP 'CASE X)
                              (AND (DIS-OP 'FORM::CHOICES (TERM-ARGN X 1)))))))
             (UNP-NAME (QUOTE NIL) V1)
             (UNP-ALT V0
                      (((FORM-UNP-EXP-AUX-ALT-1 V0 V1))
                       ((FORM-UNP-EXP-AUX-ALT-2 V0 V1))
                       ((FORM-UNP-EXP-AUX-ALT-3 V0 V1))
                       ((FORM-UNP-EXP-AUX-ALT-4 V0 V1))
                       ((FORM-UNP-EXP-AUX-ALT-5 V0 V1))
                       ((FORM-UNP-EXP-AUX-ALT-6 V0 V1))
                       ((FORM-UNP-EXP-AUX-ALT-7 V0 V1))
                       ((FORM-UNP-EXP-AUX-ALT-8 V0 V1))
                       ((FORM-UNP-EXP-AUX-ALT-9 V0 V1))
                       ((FORM-UNP-EXP-AUX-ALT-10 V0 V1)))))))) 



(DEFUN FORM-UNP-EXP-AUX-ALT-1 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
    (UNP-LT 'SBST::ID V1))) 



(DEFUN FORM-UNP-EXP-AUX-ALT-2 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
    (UNP-LT 'SBST::NUMBER V1))) 



(DEFUN FORM-UNP-EXP-AUX-ALT-3 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
    (UPATS
     ((:PARSE)
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-LIST-CONST)
                  (UNP-NAME (QUOTE NIL) V2)
                  (UNP-SEQ
                   (((UNP-KEYWORD 'SBST::<))
                    ((UNP-UTERM V2
                                ((UNP-DOUBLE-REPT V2
                                                  ((UNP-UTERM V3
                                                              ((UNP-BIND
                                                                'NONTERMINAL_
                                                                V3)
                                                               (UNP-NAME 'EXP
                                                                      V3)
                                                               (UNP-NT
                                                                FORM-UNP-EXP V3))))
                                                  ((UNP-KEYWORD 'SBST::|,|)) V3
                                                  (MAKE-BP :VALUE 2
                                                           :UNITED-FLAG NIL
                                                           :SPACES NIL :CRS NIL
                                                           :FORMAT (LIST))
                                                  (MAKE-BP :VALUE 0
                                                           :UNITED-FLAG NIL
                                                           :SPACES NIL :CRS NIL
                                                           :FORMAT (LIST))))))
                    ((UNP-KEYWORD 'SBST::>)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))
     (T
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-LIST-CONST)
                  (UNP-NAME (QUOTE NIL) V2)
                  (UNP-SEQ
                   (((UNP-KEYWORD 'SBST::<))
                    ((UNP-UTERM V2
                                ((UNP-DOUBLE-REPT V2
                                                  ((UNP-UTERM V3
                                                              ((UNP-BIND
                                                                'NONTERMINAL_
                                                                V3)
                                                               (UNP-NAME 'EXP
                                                                      V3)
                                                               (UNP-NT
                                                                FORM-UNP-EXP V3))))
                                                  ((UNP-KEYWORD 'SBST::|,|)) V3
                                                  (MAKE-BP :VALUE 2
                                                           :UNITED-FLAG NIL
                                                           :SPACES NIL :CRS NIL
                                                           :FORMAT (LIST))
                                                  (MAKE-BP :VALUE -100
                                                           :UNITED-FLAG
                                                           (LIST 1) :SPACES NIL
                                                           :CRS NIL :FORMAT
                                                           (LIST))))))
                    ((UNP-KEYWORD 'SBST::>)))
                   ((MAKE-BP :VALUE 200 :UNITED-FLAG NIL :SPACES 0 :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 200 :UNITED-FLAG NIL :SPACES 0 :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))))) 



(DEFUN FORM-UNP-EXP-AUX-ALT-4 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
    (UPATS
     ((:PARSE)
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'FUNCALL)
                  (UNP-NAME 'ID V2) (UNP-LIST-CONST) (UNP-NAME (QUOTE NIL) V3)
                  (UNP-SEQ
                   (((UNP-LT 'SBST::ID V2)) ((UNP-KEYWORD 'SBST::|(|))
                    ((UNP-UTERM V3
                                ((UNP-DOUBLE-REPT V3
                                                  ((UNP-UTERM V4
                                                              ((UNP-BIND
                                                                'NONTERMINAL_
                                                                V4)
                                                               (UNP-NAME 'EXP
                                                                      V4)
                                                               (UNP-NT
                                                                FORM-UNP-EXP V4))))
                                                  ((UNP-KEYWORD 'SBST::|,|)) V4
                                                  (MAKE-BP :VALUE 2
                                                           :UNITED-FLAG NIL
                                                           :SPACES NIL :CRS NIL
                                                           :FORMAT (LIST))
                                                  (MAKE-BP :VALUE 0
                                                           :UNITED-FLAG NIL
                                                           :SPACES NIL :CRS NIL
                                                           :FORMAT (LIST))))))
                    ((UNP-KEYWORD 'SBST::|)|)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))
     (T
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'FUNCALL)
                  (UNP-NAME 'ID V2) (UNP-LIST-CONST) (UNP-NAME (QUOTE NIL) V3)
                  (UNP-SEQ
                   (((UNP-LT 'SBST::ID V2)) ((UNP-KEYWORD 'SBST::|(|))
                    ((UNP-UTERM V3
                                ((UNP-DOUBLE-REPT V3
                                                  ((UNP-UTERM V4
                                                              ((UNP-BIND
                                                                'NONTERMINAL_
                                                                V4)
                                                               (UNP-NAME 'EXP
                                                                      V4)
                                                               (UNP-NT
                                                                FORM-UNP-EXP V4))))
                                                  ((UNP-KEYWORD 'SBST::|,|)) V4
                                                  (MAKE-BP :VALUE 2
                                                           :UNITED-FLAG NIL
                                                           :SPACES NIL :CRS NIL
                                                           :FORMAT (LIST))
                                                  (MAKE-BP :VALUE -900
                                                           :UNITED-FLAG
                                                           (LIST 2) :SPACES NIL
                                                           :CRS NIL :FORMAT
                                                           (LIST))))))
                    ((UNP-KEYWORD 'SBST::|)|)))
                   ((MAKE-BP :VALUE 200 :UNITED-FLAG NIL :SPACES 0 :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES 0 :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 200 :UNITED-FLAG NIL :SPACES 0 :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))))) 



(DEFUN FORM-UNP-EXP-AUX-ALT-5 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
    (UPATS
     ((:PARSE)
      (UNP-UTERM V1
                 ((UNP-BIND 'JUX_ V1) (UNP-TERM-CONST 'FORM::APPL)
                  (UNP-NAME 'EXP V2) (UNP-NAME 'EXP V3)
                  (UNP-JUX ((UNP-NT FORM-UNP-EXP V2)) 'JUX
                           ((UNP-NT FORM-UNP-EXP V3))
                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST))
                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST))
                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS
                                    NIL :FORMAT (LIST))))))
     (T
      (UNP-UTERM V1
                 ((UNP-BIND 'JUX_ V1) (UNP-TERM-CONST 'FORM::APPL)
                  (UNP-NAME 'EXP V2) (UNP-NAME 'EXP V3)
                  (UNP-JUX
                   ((UNP-SEQ (((UNP-NT FORM-UNP-EXP V2)))
                             ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL
                                       :CRS NIL :FORMAT (LIST TAB-RIGHT-TOKEN)))))
                   'JUX
                   ((UNP-SEQ (((UNP-NT FORM-UNP-EXP V3)))
                             ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL
                                       :CRS NIL :FORMAT (LIST UNTAB-TOKEN)))))
                   (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                            :FORMAT (LIST TAB-RIGHT-TOKEN))
                   (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                            :FORMAT (LIST UNTAB-TOKEN))
                   (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                            :FORMAT (LIST))))))))) 



(DEFUN FORM-UNP-EXP-AUX-ALT-6 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
    (UPATS
     ((:PARSE)
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'FORM::PLUS)
                  (UNP-NAME 'EXP V2) (UNP-NAME 'EXP V3)
                  (UNP-SEQ
                   (((UNP-NT FORM-UNP-EXP V2)) ((UNP-KEYWORD 'SBST::+))
                    ((UNP-NT FORM-UNP-EXP V3)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))
     (T
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'FORM::PLUS)
                  (UNP-NAME 'EXP V2) (UNP-NAME 'EXP V3)
                  (UNP-SEQ
                   (((UNP-NT FORM-UNP-EXP V2)) ((UNP-KEYWORD 'SBST::+))
                    ((UNP-NT FORM-UNP-EXP V3)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES 2 :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES 2 :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))))) 



(DEFUN FORM-UNP-EXP-AUX-ALT-7 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
    (UPATS
     ((:PARSE)
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'FORM::MULT)
                  (UNP-NAME 'EXP V2) (UNP-NAME 'EXP V3)
                  (UNP-SEQ
                   (((UNP-NT FORM-UNP-EXP V2)) ((UNP-KEYWORD 'SBST::*))
                    ((UNP-NT FORM-UNP-EXP V3)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))
     (T
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'FORM::MULT)
                  (UNP-NAME 'EXP V2) (UNP-NAME 'EXP V3)
                  (UNP-SEQ
                   (((UNP-NT FORM-UNP-EXP V2)) ((UNP-KEYWORD 'SBST::*))
                    ((UNP-NT FORM-UNP-EXP V3)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES 1 :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES 1 :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))))) 



(DEFUN FORM-UNP-EXP-AUX-ALT-8 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
    (UNP-UTERM V1
               ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'FORM::ATSIGN)
                (UNP-NAME 'EXP V2) (UNP-NAME 'EXP V3)
                (UNP-SEQ
                 (((UNP-NT FORM-UNP-EXP V2)) ((UNP-KEYWORD 'SBST::@))
                  ((UNP-NT FORM-UNP-EXP V3)))
                 ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST))
                  (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                           :FORMAT (LIST)))))))) 



(DEFUN FORM-UNP-EXP-AUX-ALT-9 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
    (UPATS
     ((:PARSE)
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1)
                  (DIS-OPT V4 (LAMBDA (X)
                                (AND (DIS-OP 'IF X)))
                           (LAMBDA (X)
                             (AND (DIS-OP 'FORM::IF-ELSE X))))
                  (UNP-OPT-AUG V4
                               ((UNP-TERM-CONST 'IF) (UNP-NAME 'EXP V2)
                                (UNP-NAME 'EXP V3))
                               ((UNP-TERM-CONST 'FORM::IF-ELSE)
                                (UNP-NAME 'EXP V2) (UNP-NAME 'EXP V3)
                                (UNP-NAME 'EXP V5)))
                  (UNP-SEQ
                   (((UNP-KEYWORD 'SBST::IF)) ((UNP-NT FORM-UNP-EXP V2))
                    ((UNP-KEYWORD 'SBST::THEN)) ((UNP-NT FORM-UNP-EXP V3))
                    ((UNP-OPT V4
                              ((UNP-SEQ
                                (((UNP-KEYWORD 'SBST::ELSE))
                                 ((UNP-NT FORM-UNP-EXP V5)))
                                ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL
                                          :CRS NIL :FORMAT (LIST))
                                 (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL
                                          :CRS NIL :FORMAT (LIST)))))))
                    ((UNP-KEYWORD 'SBST::ENDIF)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))
     (T
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1)
                  (DIS-OPT V4 (LAMBDA (X)
                                (AND (DIS-OP 'IF X)))
                           (LAMBDA (X)
                             (AND (DIS-OP 'FORM::IF-ELSE X))))
                  (UNP-OPT-AUG V4
                               ((UNP-TERM-CONST 'IF) (UNP-NAME 'EXP V2)
                                (UNP-NAME 'EXP V3))
                               ((UNP-TERM-CONST 'FORM::IF-ELSE)
                                (UNP-NAME 'EXP V2) (UNP-NAME 'EXP V3)
                                (UNP-NAME 'EXP V5)))
                  (UNP-SEQ
                   (((UNP-KEYWORD 'SBST::IF)) ((UNP-NT FORM-UNP-EXP V2))
                    ((UNP-KEYWORD 'SBST::THEN)) ((UNP-NT FORM-UNP-EXP V3))
                    ((UNP-OPT V4
                              ((UNP-SEQ
                                (((UNP-KEYWORD 'SBST::ELSE))
                                 ((UNP-NT FORM-UNP-EXP V5)))
                                ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL
                                          :CRS NIL :FORMAT (LIST))
                                 (MAKE-BP :VALUE -268435456 :UNITED-FLAG NIL
                                          :SPACES NIL :CRS 0 :FORMAT
                                          (LIST
                                           (MAKE-TOKEN :KIND :WHITESPACE
                                                       :SUBKIND :CR :VALUE 1))))))))
                    ((UNP-KEYWORD 'SBST::ENDIF)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST TAB-RIGHT-TOKEN))
                    (MAKE-BP :VALUE -268435456 :UNITED-FLAG NIL :SPACES NIL
                             :CRS 0 :FORMAT
                             (LIST
                              (MAKE-TOKEN :KIND :WHITESPACE :SUBKIND :CR :VALUE
                                          1)))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE -268435456 :UNITED-FLAG NIL :SPACES NIL
                             :CRS 0 :FORMAT
                             (LIST
                              (MAKE-TOKEN :KIND :WHITESPACE :SUBKIND :CR :VALUE
                                          1)))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST UNTAB-TOKEN)))))))))) 



(DEFUN FORM-UNP-EXP-AUX-ALT-10 (V0 V1)
  (ERGO-IGNORE-IF-UNUSED V0 V1)
  (LET (V2
        V3
        V4
        V5
        V6
        V7)
    (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
    (UPATS
     ((:PARSE)
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'CASE) (UNP-NAME 'EXP V2)
                  (UNP-LIST-CONST) (UNP-NAME (QUOTE NIL) V3)
                  (UNP-SEQ
                   (((UNP-KEYWORD 'SBST::CASE)) ((UNP-NT FORM-UNP-EXP V2))
                    ((UNP-KEYWORD 'SBST::OF))
                    ((UNP-UTERM V3
                                ((UNP-REPT V3
                                           ((UNP-UTERM V4
                                                       ((UNP-BIND 'SEQ_ V4)
                                                        (UNP-NAME (QUOTE NIL)
                                                                  V7)
                                                        (UNP-BIND '#:G27371 V7)
                                                        (UNP-TERM-CONST
                                                         'FORM::ENTRY)
                                                        (UNP-NAME 'EXP V5)
                                                        (UNP-NAME 'EXP V6)
                                                        (UNP-SEQ
                                                         (((UNP-NT FORM-UNP-EXP
                                                                   V5))
                                                          ((UNP-KEYWORD
                                                            'SBST::|:|))
                                                          ((UNP-NT FORM-UNP-EXP
                                                                   V6))
                                                          ((UNP-KEYWORD
                                                            'SBST::|;|)))
                                                         ((MAKE-BP :VALUE 0
                                                                   :UNITED-FLAG
                                                                   NIL :SPACES
                                                                   NIL :CRS NIL
                                                                   :FORMAT
                                                                   (LIST))
                                                          (MAKE-BP :VALUE 0
                                                                   :UNITED-FLAG
                                                                   NIL :SPACES
                                                                   NIL :CRS NIL
                                                                   :FORMAT
                                                                   (LIST))
                                                          (MAKE-BP :VALUE 0
                                                                   :UNITED-FLAG
                                                                   NIL :SPACES
                                                                   NIL :CRS NIL
                                                                   :FORMAT
                                                                   (LIST))
                                                          (MAKE-BP :VALUE 0
                                                                   :UNITED-FLAG
                                                                   NIL :SPACES
                                                                   NIL :CRS NIL
                                                                   :FORMAT
                                                                   (LIST)))))))
                                           V4
                                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL
                                                    :SPACES NIL :CRS NIL
                                                    :FORMAT (LIST))))))
                    ((UNP-KEYWORD 'SBST::ENDCASE)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST)))))))
     (T
      (UNP-UTERM V1
                 ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'CASE) (UNP-NAME 'EXP V2)
                  (UNP-LIST-CONST) (UNP-NAME (QUOTE NIL) V3)
                  (UNP-SEQ
                   (((UNP-KEYWORD 'SBST::CASE)) ((UNP-NT FORM-UNP-EXP V2))
                    ((UNP-KEYWORD 'SBST::OF))
                    ((UNP-UTERM V3
                                ((UNP-REPT V3
                                           ((UNP-UTERM V4
                                                       ((UNP-BIND 'SEQ_ V4)
                                                        (UNP-NAME (QUOTE NIL)
                                                                  V7)
                                                        (UNP-BIND '#:G27373 V7)
                                                        (UNP-TERM-CONST
                                                         'FORM::ENTRY)
                                                        (UNP-NAME 'EXP V5)
                                                        (UNP-NAME 'EXP V6)
                                                        (UNP-SEQ
                                                         (((UNP-NT FORM-UNP-EXP
                                                                   V5))
                                                          ((UNP-KEYWORD
                                                            'SBST::|:|))
                                                          ((UNP-NT FORM-UNP-EXP
                                                                   V6))
                                                          ((UNP-KEYWORD
                                                            'SBST::|;|)))
                                                         ((MAKE-BP :VALUE 0
                                                                   :UNITED-FLAG
                                                                   NIL :SPACES
                                                                   NIL :CRS NIL
                                                                   :FORMAT
                                                                   (LIST))
                                                          (MAKE-BP :VALUE 0
                                                                   :UNITED-FLAG
                                                                   NIL :SPACES
                                                                   NIL :CRS NIL
                                                                   :FORMAT
                                                                   (LIST))
                                                          (MAKE-BP :VALUE 0
                                                                   :UNITED-FLAG
                                                                   NIL :SPACES
                                                                   NIL :CRS NIL
                                                                   :FORMAT
                                                                   (LIST))
                                                          (MAKE-BP :VALUE
                                                                   -268435456
                                                                   :UNITED-FLAG
                                                                   NIL :SPACES
                                                                   NIL :CRS 0
                                                                   :FORMAT
                                                                   (LIST
                                                                    (MAKE-TOKEN
                                                                     :KIND
                                                                     :WHITESPACE
                                                                     :SUBKIND
                                                                     :CR :VALUE
                                                                      1))))))))
                                           V4
                                           (MAKE-BP :VALUE 0 :UNITED-FLAG NIL
                                                    :SPACES NIL :CRS NIL
                                                    :FORMAT (LIST))))))
                    ((UNP-KEYWORD 'SBST::ENDCASE)))
                   ((MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES 2 :CRS NIL
                             :FORMAT (LIST TAB-LEFT-TOKEN))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST))
                    (MAKE-BP :VALUE -268435456 :UNITED-FLAG NIL :SPACES NIL
                             :CRS 0 :FORMAT
                             (LIST
                              (MAKE-TOKEN :KIND :WHITESPACE :SUBKIND :CR :VALUE
                                          1)))
                    (MAKE-BP :VALUE 0 :UNITED-FLAG NIL :SPACES NIL :CRS NIL
                             :FORMAT (LIST UNTAB-TOKEN))
                    (MAKE-BP :VALUE -268435456 :UNITED-FLAG NIL :SPACES NIL
                             :CRS 0 :FORMAT
                             (LIST
                              (MAKE-TOKEN :KIND :WHITESPACE :SUBKIND :CR :VALUE
                                          1))))))))))) 



(DEFUN FORM-DIS-EXP (AS)
  (OR (IS-NT-OPSIG? 'EXP AS)
      ((LAMBDA (X)
         (OR ((LAMBDA (X)
                (DIS-OP 'CASE X)) X)
             ((LAMBDA (X)
                (DIS-OP 'FORM::IF-ELSE X)) X)
             ((LAMBDA (X)
                (DIS-OP 'IF X)) X)
             ((LAMBDA (X)
                (DIS-OP 'FORM::ATSIGN X)) X)
             ((LAMBDA (X)
                (DIS-OP 'FORM::MULT X)) X)
             ((LAMBDA (X)
                (DIS-OP 'FORM::PLUS X)) X)
             ((LAMBDA (X)
                (DIS-OP 'FORM::APPL X)) X)
             ((LAMBDA (X)
                (DIS-OP 'FUNCALL X)) X)
             ((LAMBDA (X)
                (DIS-OP 'FORM::TUPLE X)) X)
             ((LAMBDA (X)
                (DIS-LT 'SBST::NUMBER X)) X)
             ((LAMBDA (X)
                (DIS-LT 'SBST::ID X)) X)))
       AS))) 

