;;; -*- Mode: Lisp; Package: PASCAL -*-
(in-package "PASCAL")  ;; creates package for abstract syntax. 

(in-package "PASCAL")  ;; enters package for generated code.  

(use-package '("ERGOLISP" "OPER" "OCC" "TERM" "SORT" "SB-RUNTIME" "LANG" "NEWATTR"))


(export '())

(DEFPARAMETER PASCAL-KEYWORD-LIST
              '(SBST::|)| SBST::|(| SBST::<= SBST::< SBST::= SBST::> SBST::>=
                SBST::<> SBST::IN SBST::+ SBST::- SBST::OR SBST::AND SBST::*
                SBST::MOD SBST::DIV SBST::- SBST::+ SBST::NOT SBST::|,| SBST::[
                SBST::] SBST::|.| SBST::^ SBST::|:=| SBST::END SBST::|;|
                SBST::BEGIN SBST::ELSE SBST::THEN SBST::IF SBST::UNTIL
                SBST::|;| SBST::REPEAT SBST::DO SBST::WHILE SBST::DO
                SBST::DOWNTO SBST::TO SBST::|:=| SBST::FOR SBST::END SBST::|;|
                SBST::OF SBST::CASE SBST::DO SBST::WITH SBST::GOTO SBST::|:|
                SBST::|..| SBST::PROGRAM SBST::PROGRAM SBST::LABEL SBST::CONST
                SBST::TYPE SBST::VAR SBST::FUNCTION SBST::PROCEDURE
                SBST::PACKED SBST::FILE SBST::PACKED SBST::RECORD SBST::PACKED
                SBST::ARRAY SBST::PACKED SBST::SET SBST::NULL))
(DEFPARAMETER PASCAL-SINGLE-CHAR-OP-LIST
              '(#\( #\) #\^ #\* #\- #\+ #\= #\[ #\] #\; #\,))
(DEFPARAMETER PASCAL-MULTI-CHAR-OP-LIST
              '((#\. . LEX-.) (#\: . |LEX-:|) (#\> . LEX->) (#\< . LEX-<)))
(DEFPARAMETER PASCAL-ALL-OPERATORS-LIST
              '(SBST::|(| SBST::|)| SBST::^ SBST::* SBST::- SBST::+ SBST::=
                SBST::[ SBST::] SBST::< SBST::> SBST::<= SBST::>= SBST::<>
                SBST::|:=| SBST::|;| SBST::|:| SBST::|,| SBST::|..| SBST::|.|))
(DEFPARAMETER PASCAL-NEW-LINE-COMMENT-CHAR NIL)
(DEFPARAMETER PASCAL-OPEN-COMMENT-CHAR #\{)
(DEFPARAMETER PASCAL-CLOSE-COMMENT-CHAR #\})
(DEFPARAMETER PASCAL-ESCAPE-CHAR NIL)
(DEFPARAMETER PASCAL-CASE-SENSITIVE NIL)
(DEFPARAMETER PASCAL-STRING-CHAR #\")
(DEFPARAMETER PASCAL-KEYWORD-CHAR NIL)
(DEFPARAMETER PASCAL-LITERAL-CHAR NIL)
(DEFPARAMETER PASCAL-RESTRICTED-CHARS
              (REDUCE #'(LAMBDA (R S)
                                (UNION R S :TEST #'CHAR=))
                      (LIST PASCAL-SINGLE-CHAR-OP-LIST
                            (IF PASCAL-NEW-LINE-COMMENT-CHAR
                                (LIST PASCAL-NEW-LINE-COMMENT-CHAR))
                            (IF PASCAL-OPEN-COMMENT-CHAR
                                (LIST PASCAL-OPEN-COMMENT-CHAR))
                            (IF PASCAL-CLOSE-COMMENT-CHAR
                                (LIST PASCAL-CLOSE-COMMENT-CHAR))
                            (IF PASCAL-ESCAPE-CHAR
                                (LIST PASCAL-ESCAPE-CHAR))
                            (IF PASCAL-STRING-CHAR
                                (LIST PASCAL-STRING-CHAR))
                            (IF PASCAL-KEYWORD-CHAR
                                (LIST PASCAL-KEYWORD-CHAR))
                            (IF PASCAL-LITERAL-CHAR
                                (LIST PASCAL-LITERAL-CHAR)))))
(DEFVAR *PASCAL-KEYWORD-TABLE* NIL)
(DEFUN INIT-LEXER-AUX
       (LEXSTREAM)
       (INIT-LEXICAL-READTABLE LEXSTREAM
                               :SINGLE-CHAR-OP-LIST
                               PASCAL-SINGLE-CHAR-OP-LIST
                               :NEW-LINE-COMMENT-CHAR
                               PASCAL-NEW-LINE-COMMENT-CHAR
                               :OPEN-COMMENT-CHAR
                               PASCAL-OPEN-COMMENT-CHAR
                               :ESCAPE-CHAR
                               PASCAL-ESCAPE-CHAR
                               :MULTI-CHAR-OP-LIST
                               PASCAL-MULTI-CHAR-OP-LIST))

(DEFUN INIT-LEXER
       (LEXSTREAM)
       (INIT-LEXER-AUX LEXSTREAM)
       (IF PASCAL-STRING-CHAR
           (LEXICAL-MAKE-MACRO LEXSTREAM
                               PASCAL-STRING-CHAR
                               #'READ-SB-STRING))
       (IF PASCAL-KEYWORD-CHAR
           (LEXICAL-MAKE-MACRO LEXSTREAM
                               PASCAL-KEYWORD-CHAR
                               #'READ-KEYWORD-STRING))
       (IF PASCAL-LITERAL-CHAR
           (LEXICAL-MAKE-MACRO LEXSTREAM
                               PASCAL-LITERAL-CHAR
                               #'READ-LITERAL)))

(DEFUN LEX-<
       (STREAM SYMBOL)
       (DECLARE (IGNORE SYMBOL))
       (LET (HOLDCHAR)
         (SETF HOLDCHAR
               (LEXICAL-READ-CHAR STREAM :EOF))
         (IF (AND PASCAL-ESCAPE-CHAR
                  (CHAR= HOLDCHAR PASCAL-ESCAPE-CHAR))
             (SETF HOLDCHAR
                   (LEXICAL-READ-CHAR STREAM :EOF)))
         (COND ((CHAR= HOLDCHAR #\=) 'SBST::<=)
               ((CHAR= HOLDCHAR #\>) 'SBST::<>)
               (T (LEXICAL-UNREAD-CHAR STREAM) 'SBST::<))))
(DEFUN LEX->
       (STREAM SYMBOL)
       (DECLARE (IGNORE SYMBOL))
       (LET (HOLDCHAR)
         (SETF HOLDCHAR
               (LEXICAL-READ-CHAR STREAM :EOF))
         (IF (AND PASCAL-ESCAPE-CHAR
                  (CHAR= HOLDCHAR PASCAL-ESCAPE-CHAR))
             (SETF HOLDCHAR
                   (LEXICAL-READ-CHAR STREAM :EOF)))
         (COND ((CHAR= HOLDCHAR #\=) 'SBST::>=)
               (T (LEXICAL-UNREAD-CHAR STREAM) 'SBST::>))))
(DEFUN |LEX-:|
       (STREAM SYMBOL)
       (DECLARE (IGNORE SYMBOL))
       (LET (HOLDCHAR)
         (SETF HOLDCHAR
               (LEXICAL-READ-CHAR STREAM :EOF))
         (IF (AND PASCAL-ESCAPE-CHAR
                  (CHAR= HOLDCHAR PASCAL-ESCAPE-CHAR))
             (SETF HOLDCHAR
                   (LEXICAL-READ-CHAR STREAM :EOF)))
         (COND ((CHAR= HOLDCHAR #\=) 'SBST::|:=|)
               (T (LEXICAL-UNREAD-CHAR STREAM) 'SBST::|:|))))
(DEFUN LEX-.
       (STREAM SYMBOL)
       (DECLARE (IGNORE SYMBOL))
       (LET (HOLDCHAR)
         (SETF HOLDCHAR
               (LEXICAL-READ-CHAR STREAM :EOF))
         (IF (AND PASCAL-ESCAPE-CHAR
                  (CHAR= HOLDCHAR PASCAL-ESCAPE-CHAR))
             (SETF HOLDCHAR
                   (LEXICAL-READ-CHAR STREAM :EOF)))
         (COND ((CHAR= HOLDCHAR #\.) 'SBST::|..|)
               (T (LEXICAL-UNREAD-CHAR STREAM) 'SBST::|.|))))
