;;; -*- Mode: Lisp; Package: PASCAL -*-
(in-package "PASCAL")  ;; creates package for abstract syntax. 

(in-package "PASCAL")  ;; enters package for generated code.  

(use-package '("ERGOLISP" "OPER" "OCC" "TERM" "SORT" "SB-RUNTIME" "LANG" "NEWATTR"))


(export '( PASCAL-UNPARSE  PASCAL-WIN-UNPARSE ))

(DEFVAR PASCAL-BRACKET-INFO
        (MAKE-HASH-TABLE :TEST #'EQ))
(CLRHASH PASCAL-BRACKET-INFO)
(MAPC
  #'(LAMBDA (ENTRY)
     (SET-BRACKET-INFO (CAR ENTRY) (CADR ENTRY) (CADDR ENTRY)
      PASCAL-BRACKET-INFO))
  '((EXP SBST::|(| SBST::|)|)))

(DEFVAR PASCAL-PREC-INFO
        (MAKE-HASH-TABLE :TEST #'EQ))
(CLRHASH PASCAL-PREC-INFO)
(MAPC #'(LAMBDA (NT)
                (INIT-PREC-INFO NT PASCAL-PREC-INFO))
      '(EXP))
(MAPC
  #'(LAMBDA (ENTRY)
     (SET-PREC-INFO (CAR ENTRY) (CADR ENTRY) (CADDR ENTRY) (CADDDR ENTRY)
      PASCAL-PREC-INFO))
  '((EXP SBST::- 0 40) (EXP SBST::+ 0 40) (EXP SBST::NOT 0 40)
    (EXP SBST::AND 1 30) (EXP SBST::MOD 1 30) (EXP SBST::DIV 1 30)
    (EXP SBST::/ 1 30) (EXP SBST::* 1 30) (EXP SBST::OR 1 20)
    (EXP SBST::- 1 20) (EXP SBST::+ 1 20) (EXP SBST::IN 1 10)
    (EXP SBST::<> 1 10) (EXP SBST::>= 1 10) (EXP SBST::> 1 10)
    (EXP SBST::= 1 10) (EXP SBST::<= 1 10) (EXP SBST::< 1 10)
    (EXP SBST::AND 2 31) (EXP SBST::MOD 2 31) (EXP SBST::DIV 2 31)
    (EXP SBST::/ 2 31) (EXP SBST::* 2 31) (EXP SBST::OR 2 21)
    (EXP SBST::- 2 21) (EXP SBST::+ 2 21) (EXP SBST::IN 2 11)
    (EXP SBST::<> 2 11) (EXP SBST::>= 2 11) (EXP SBST::> 2 11)
    (EXP SBST::= 2 11) (EXP SBST::<= 2 11) (EXP SBST::< 2 11)))

(DEFVAR PASCAL-SPACING-INFO
        (MAKE-HASH-TABLE :TEST #'EQ))
(CLRHASH PASCAL-SPACING-INFO)
(MAPC
  #'(LAMBDA (T1 T2 BP)
     (COND ((ASSOC T2 (GETHASH T1 PASCAL-SPACING-INFO)))
      (T
       (SETF (GETHASH T1 PASCAL-SPACING-INFO)
        (CONS (LIST T2 BP) (GETHASH T1 PASCAL-SPACING-INFO))))))
  'NIL
  'NIL
  'NIL)

(DEFVAR PASCAL-KEY-TOKEN-MAP
        (MAKE-HASH-TABLE :TEST #'EQ))
(DEFVAR PASCAL-KEY-ESC-TOKEN-MAP
        (IF PASCAL-ESCAPE-CHAR
            (MAKE-HASH-TABLE :TEST #'EQ)))
(DEFVAR PASCAL-LT-TOKEN-MAP
        (MAKE-HASH-TABLE :TEST #'EQUAL))
(DEFVAR PASCAL-LT-ESC-TOKEN-MAP
        (IF PASCAL-ESCAPE-CHAR
            (MAKE-HASH-TABLE :TEST #'EQUAL)))


(DEFUN PASCAL::PASCAL-UNPARSE
       (NT AS
           &KEY
           (STYLE *UNPARSE-STYLE*))
       (LET* ((*UNPARSER-OP-LIST* PASCAL-ALL-OPERATORS-LIST)
              (*KEY-TOKEN-MAP* PASCAL-KEY-TOKEN-MAP)
              (*KEY-ESC-TOKEN-MAP* PASCAL-KEY-ESC-TOKEN-MAP)
              (*LT-TOKEN-MAP* PASCAL-LT-TOKEN-MAP)
              (*LT-ESC-TOKEN-MAP* PASCAL-LT-ESC-TOKEN-MAP)
              (*APPLY-LT-DIS-FUN* #'APPLY-LEXICAL-TERMINAL-DISCRIMINATOR)
              (*APPLY-LT-DES-FUN* #'APPLY-LEXICAL-TERMINAL-DESTRUCTOR)
              (*APPLY-LT-TOKEN-CONS-FUN* #'APPLY-LT-TOKEN-CONSTRUCTOR)
              (*BRACKET-INFO* PASCAL-BRACKET-INFO)
              (*PREC-INFO* PASCAL-PREC-INFO)
              (SORT (OPSIG-OUTPUT (OPSIG-TABLE-LOOKUP (TERM-OP AS))))
              (NT-NAME
                (COND (NT)
                      ((IS-SORT-TTYPE SORT) (DS-SORT-TTYPE SORT))
                      (T 'PASCAL::PROGRAM)))
              (*CASE-SENSITIVE* PASCAL-CASE-SENSITIVE)
              (*ESCAPE-CHARACTER* PASCAL-ESCAPE-CHAR)
              (*RESTRICTED-CHARS* PASCAL-RESTRICTED-CHARS)
              (*STRING-CHAR* PASCAL-STRING-CHAR)
              (*LITERAL-CHAR* PASCAL-LITERAL-CHAR)
              (*KEYWORD-CHAR* PASCAL-KEYWORD-CHAR)
              (*UNPARSE-STYLE*
                (IF (AND STYLE
                         (NOT (CONSP STYLE)))
                    (LIST STYLE)
                    STYLE))
              (*NO-ESCAPES* (OR *NO-ESCAPES*
                                (NULL (INSERT-ESCAPES?))))
              (*CURRENT-PRINT-DEPTH* 1))
         (LET ((UTERM
                 (CASE NT-NAME
                       (PASCAL::PROGRAM (PASCAL-UNP-PROGRAM AS
                                                            :TOP-LEVEL?
                                                            T))
                       (BLOCK (PASCAL-UNP-BLOCK
                               AS
                               :TOP-LEVEL?
                               T))
                       (PASCAL::FUNCTION-LIST
                         (PASCAL-UNP-FUNCTION-LIST AS :TOP-LEVEL? T))
                       (PASCAL::HEADING
                         (PASCAL-UNP-HEADING AS :TOP-LEVEL? T))
                       (PASCAL::PARAMETER-TYPE
                         (PASCAL-UNP-PARAMETER-TYPE AS :TOP-LEVEL? T))
                       (PASCAL::MY-TYPE
                         (PASCAL-UNP-MY-TYPE AS :TOP-LEVEL? T))
                       (PASCAL::FIELD-LIST
                         (PASCAL-UNP-FIELD-LIST AS :TOP-LEVEL? T))
                       (PASCAL::SIMPLE-TYPE
                         (PASCAL-UNP-SIMPLE-TYPE AS :TOP-LEVEL? T))
                       (PASCAL::STATEMENT
                         (PASCAL-UNP-STATEMENT AS :TOP-LEVEL? T))
                       (PASCAL::REAL-STATEMENT
                         (PASCAL-UNP-REAL-STATEMENT AS :TOP-LEVEL? T))
                       (EXP (PASCAL-UNP-EXP AS :TOP-LEVEL? T))
                       (VARIABLE (PASCAL-UNP-VARIABLE AS :TOP-LEVEL? T))
                       (PASCAL::CONSTANT
                         (PASCAL-UNP-CONSTANT AS :TOP-LEVEL? T))
                       (T (UNPARSE-RUNTIME-ERROR :NT-NOT-UNPARSABLE
                                                 NT-NAME)
                          NIL))))
           UTERM)))

(DEFUN PASCAL::PASCAL-WIN-UNPARSE
       (UTERM WIDTH
              &KEY
              (FONTWIDTH SB-DEFFONTWIDTH)
              (FONTHEIGHT SB-DEFFONTHEIGHT))
       (LET* ((*CASE-SENSITIVE* PASCAL-CASE-SENSITIVE)
              (*UNPARSER-OP-LIST* PASCAL-ALL-OPERATORS-LIST)
              (*SPACING-INFO* PASCAL-SPACING-INFO))
         (FORMAT-UTERM UTERM
                       WIDTH
                       :FONTWIDTH
                       FONTWIDTH
                       :FONTHEIGHT
                       FONTHEIGHT)))



(DEFUN PASCAL-UNP-PROGRAM
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-PROGRAM-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-BLOCK
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-BLOCK-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-FUNCTION-LIST
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-FUNCTION-LIST-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-HEADING
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-HEADING-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-PARAMETER-TYPE
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-PARAMETER-TYPE-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-MY-TYPE
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-MY-TYPE-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-FIELD-LIST
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-FIELD-LIST-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-SIMPLE-TYPE
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-SIMPLE-TYPE-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-STATEMENT
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-STATEMENT-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-REAL-STATEMENT
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-REAL-STATEMENT-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-EXP
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-EXP-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-VARIABLE
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-VARIABLE-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-CONSTANT
       (AS &KEY (TOP-LEVEL? NIL))
       (MEMO-UTERM AS
                   #'PASCAL-UNP-CONSTANT-AUX
                   :TOP-LEVEL?
                   TOP-LEVEL?))



(DEFUN PASCAL-UNP-PROGRAM-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4)
         (SETF V0 AS)
         (NT-UNP 'PASCAL::PROGRAM
                 AS
                 ((UNP-UTERM V0
                             ((UNP-BIND 'SEQ_ V0)
                               (UNP-TERM-CONST 'PASCAL::PROGRAM)
                               (UNP-NAME 'ID V1)
                               (UNP-LIST-CONST)
                               (UNP-NAME 'DOUBLESTAR V2)
                               (UNP-NAME 'BLOCK V4)
                               (UNP-SEQ
                                 (((UNP-KEYWORD 'SBST::PROGRAM))
                                   ((UNP-LT 'SBST::ID V1))
                                   ((UNP-KEYWORD 'SBST::|(|))
                                   ((UNP-UTERM V2
                                               ((UNP-DOUBLE-REPT V2
                                                                 ((UNP-UTERM V3
                                                                      ((UNP-LT
                                                                      'SBST::ID
                                                                      V3))))
                                                                 ((UNP-KEYWORD
                                                                    'SBST::|,|))
                                                                 V3
                                                                 (MAKE-BP
                                                                   :VALUE
                                                                   2
                                                                   :UNITED-FLAG
                                                                   NIL
                                                                   :SPACES
                                                                   NIL
                                                                   :CRS
                                                                   NIL
                                                                   :FORMAT
                                                                   (LIST))
                                                                 (MAKE-BP
                                                                   :VALUE
                                                                   0
                                                                   :UNITED-FLAG
                                                                   NIL
                                                                   :SPACES
                                                                   NIL
                                                                   :CRS
                                                                   NIL
                                                                   :FORMAT
                                                                   (LIST))))))
                                   ((UNP-KEYWORD 'SBST::|)|))
                                   ((UNP-KEYWORD 'SBST::|;|))
                                   ((UNP-NT PASCAL-UNP-BLOCK V4))
                                   ((UNP-KEYWORD 'SBST::PROGRAM)))
                                 ((MAKE-BP :VALUE
                                           0
                                           :UNITED-FLAG
                                           NIL
                                           :SPACES
                                           NIL
                                           :CRS
                                           NIL
                                           :FORMAT
                                           (LIST))
                                   (MAKE-BP :VALUE
                                            0
                                            :UNITED-FLAG
                                            NIL
                                            :SPACES
                                            NIL
                                            :CRS
                                            NIL
                                            :FORMAT
                                            (LIST))
                                   (MAKE-BP :VALUE
                                            0
                                            :UNITED-FLAG
                                            NIL
                                            :SPACES
                                            NIL
                                            :CRS
                                            NIL
                                            :FORMAT
                                            (LIST))
                                   (MAKE-BP :VALUE
                                            0
                                            :UNITED-FLAG
                                            NIL
                                            :SPACES
                                            NIL
                                            :CRS
                                            NIL
                                            :FORMAT
                                            (LIST))
                                   (MAKE-BP :VALUE
                                            0
                                            :UNITED-FLAG
                                            NIL
                                            :SPACES
                                            NIL
                                            :CRS
                                            NIL
                                            :FORMAT
                                            (LIST))
                                   (MAKE-BP :VALUE
                                            0
                                            :UNITED-FLAG
                                            NIL
                                            :SPACES
                                            NIL
                                            :CRS
                                            NIL
                                            :FORMAT
                                            (LIST))
                                   (MAKE-BP :VALUE
                                            0
                                            :UNITED-FLAG
                                            NIL
                                            :SPACES
                                            NIL
                                            :CRS
                                            NIL
                                            :FORMAT
                                            (LIST))
                                   (MAKE-BP :VALUE
                                            0
                                            :UNITED-FLAG
                                            NIL
                                            :SPACES
                                            NIL
                                            :CRS
                                            NIL
                                            :FORMAT
                                            (LIST))))))))))



(DEFUN PASCAL-UNP-BLOCK-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3
             V4
             V5
             V6
             V7
             V8
             V9
             V10
             V11
             V12
             V13
             V14
             V15
             V16
             V17
             V18
             V19
             V20
             V21
             V22
             V23
             V24
             V25
             V26
             V27
             V28
             V29
             V30
             V31
             V32
             V33
             V34
             V35)
         (ERGO-IGNORE-IF-UNUSED V0
                                V1
                                V2
                                V3
                                V4
                                V5
                                V6
                                V7
                                V8
                                V9
                                V10
                                V11
                                V12
                                V13
                                V14
                                V15
                                V16
                                V17
                                V18
                                V19
                                V20
                                V21
                                V22
                                V23
                                V24
                                V25
                                V26
                                V27
                                V28
                                V29
                                V30
                                V31
                                V32
                                V33
                                V34
                                V35)
         (SETF V0 AS)
         (NT-UNP 'BLOCK
                 AS
                 ((UNP-UTERM V0
                             ((UNP-BIND 'SEQ_ V0) (UNP-TERM-CONST 'BLOCK)
                                                  (UNP-NAME 'OPT V2)
                                                  (UNP-NAME 'OPT V7)
                                                  (UNP-NAME 'OPT V15)
                                                  (UNP-NAME 'OPT V23)
                                                  (UNP-LIST-CONST)
                                                  (UNP-NAME 'STAR V31)
                                                  (UNP-LIST-CONST)
                                                  (UNP-NAME 'DOUBLESTAR
                                                            V34)
                                                  (UNP-SEQ
                                                    (((UNP-BIND 'OPT_1 V2)
                                                       (DIS-OPT V1
                                                                (LAMBDA (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'PASCAL::BLOCK-NULL-1
                                                                      X)))
                                                                (LAMBDA (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'LABELS
                                                                      X))))
                                                       (UNP-OPT-AUG V1
                                                                    ((UNP-NULL-CONST))
                                                                    ((UNP-NAME
                                                                      'NIL
                                                                      V3)))
                                                       (UNP-OPT V1
                                                                ((UNP-UTERM V3
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V3)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'DOUBLEPLUS
                                                                      V4)
                                                                      (UNP-SEQ
                                                                      (((UNP-KEYWORD
                                                                      'SBST::LABEL))
                                                                      ((UNP-UTERM
                                                                      V4
                                                                      ((UNP-DOUBLE-REPT
                                                                      V4
                                                                      ((UNP-UTERM
                                                                      V5
                                                                      ((UNP-LT
                                                                      'SBST::NUMBER
                                                                      V5))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|,|))
                                                                      V5
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))))
                                                      ((UNP-BIND 'OPT_2
                                                                 V7)
                                                        (DIS-OPT V6
                                                                 (LAMBDA (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'PASCAL::BLOCK-NULL-2
                                                                      X)))
                                                                 (LAMBDA (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'PASCAL::CONSTANTS
                                                                      X))))
                                                        (UNP-OPT-AUG V6
                                                                     ((UNP-NULL-CONST))
                                                                     ((UNP-NAME
                                                                      'NIL
                                                                      V8)))
                                                        (UNP-OPT V6
                                                                 ((UNP-UTERM V8
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V8)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'NIL
                                                                      V9)
                                                                      (UNP-SEQ
                                                                      (((UNP-KEYWORD
                                                                      'SBST::CONST))
                                                                      ((UNP-UTERM
                                                                      V9
                                                                      ((UNP-REPT
                                                                      V9
                                                                      ((UNP-UTERM
                                                                      V10
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V10)
                                                                      (UNP-NAME
                                                                      'NIL
                                                                      V13)
                                                                      (UNP-BIND
                                                                      '#:G61425
                                                                      V13)
                                                                      (UNP-TERM-CONST
                                                                      'PASCAL::CONST-ENTRY)
                                                                      (UNP-NAME
                                                                      'ID
                                                                      V11)
                                                                      (UNP-NAME
                                                                      'CONSTANT
                                                                      V12)
                                                                      (UNP-SEQ
                                                                      (((UNP-LT
                                                                      'SBST::ID
                                                                      V11))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::=))
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-CONSTANT
                                                                      V12))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      V10
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))))
                                                      ((UNP-BIND 'OPT_3
                                                                 V15)
                                                        (DIS-OPT V14
                                                                 (LAMBDA (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'PASCAL::BLOCK-NULL-3
                                                                      X)))
                                                                 (LAMBDA (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'PASCAL::TYPES
                                                                      X))))
                                                        (UNP-OPT-AUG V14
                                                                     ((UNP-NULL-CONST))
                                                                     ((UNP-NAME
                                                                      'NIL
                                                                      V16)))
                                                        (UNP-OPT V14
                                                                 ((UNP-UTERM
                                                                    V16
                                                                    ((UNP-BIND
                                                                      'SEQ_
                                                                      V16)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'NIL
                                                                      V17)
                                                                      (UNP-SEQ
                                                                      (((UNP-KEYWORD
                                                                      'SBST::TYPE))
                                                                      ((UNP-UTERM
                                                                      V17
                                                                      ((UNP-REPT
                                                                      V17
                                                                      ((UNP-UTERM
                                                                      V18
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V18)
                                                                      (UNP-NAME
                                                                      'NIL
                                                                      V21)
                                                                      (UNP-BIND
                                                                      '#:G61427
                                                                      V21)
                                                                      (UNP-TERM-CONST
                                                                      'PASCAL::TYPE-ENTRY)
                                                                      (UNP-NAME
                                                                      'ID
                                                                      V19)
                                                                      (UNP-NAME
                                                                      'MY-TYPE
                                                                      V20)
                                                                      (UNP-SEQ
                                                                      (((UNP-LT
                                                                      'SBST::ID
                                                                      V19))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::=))
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-MY-TYPE
                                                                      V20))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      V18
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))))
                                                      ((UNP-BIND 'OPT_4
                                                                 V23)
                                                        (DIS-OPT V22
                                                                 (LAMBDA (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'PASCAL::BLOCK-NULL-4
                                                                      X)))
                                                                 (LAMBDA (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'PASCAL::VARIABLES
                                                                      X))))
                                                        (UNP-OPT-AUG V22
                                                                     ((UNP-NULL-CONST))
                                                                     ((UNP-NAME
                                                                      'NIL
                                                                      V24)))
                                                        (UNP-OPT V22
                                                                 ((UNP-UTERM
                                                                    V24
                                                                    ((UNP-BIND
                                                                      'SEQ_
                                                                      V24)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'NIL
                                                                      V25)
                                                                      (UNP-SEQ
                                                                      (((UNP-KEYWORD
                                                                      'SBST::VAR))
                                                                      ((UNP-UTERM
                                                                      V25
                                                                      ((UNP-REPT
                                                                      V25
                                                                      ((UNP-UTERM
                                                                      V26
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V26)
                                                                      (UNP-NAME
                                                                      'NIL
                                                                      V30)
                                                                      (UNP-BIND
                                                                      '#:G61429
                                                                      V30)
                                                                      (UNP-TERM-CONST
                                                                      'PASCAL::VAR-ENTRY)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'DOUBLEPLUS
                                                                      V27)
                                                                      (UNP-NAME
                                                                      'MY-TYPE
                                                                      V29)
                                                                      (UNP-SEQ
                                                                      (((UNP-UTERM
                                                                      V27
                                                                      ((UNP-DOUBLE-REPT
                                                                      V27
                                                                      ((UNP-UTERM
                                                                      V28
                                                                      ((UNP-LT
                                                                      'SBST::ID
                                                                      V28))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|,|))
                                                                      V28
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|:|))
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-MY-TYPE
                                                                      V29))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      V26
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))))
                                                      ((UNP-UTERM V31
                                                                  ((UNP-REPT
                                                                     V31
                                                                     ((UNP-UTERM
                                                                      V32
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V32)
                                                                      (UNP-NAME
                                                                      'FUNCTION-LIST
                                                                      V33)
                                                                      (UNP-SEQ
                                                                      (((UNP-NT
                                                                      PASCAL-UNP-FUNCTION-LIST
                                                                      V33))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                     V32
                                                                     (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                      ((UNP-SEQ
                                                         (((UNP-KEYWORD
                                                             'SBST::BEGIN))
                                                           ((UNP-UTERM V34
                                                                      ((UNP-DOUBLE-REPT
                                                                      V34
                                                                      ((UNP-UTERM
                                                                      V35
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-STATEMENT
                                                                      V35))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|))
                                                                      V35
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                           ((UNP-KEYWORD
                                                              'SBST::END)))
                                                         ((MAKE-BP :VALUE
                                                                   0
                                                                   :UNITED-FLAG
                                                                   NIL
                                                                   :SPACES
                                                                   NIL
                                                                   :CRS
                                                                   NIL
                                                                   :FORMAT
                                                                   (LIST))
                                                           (MAKE-BP :VALUE
                                                                    0
                                                                    :UNITED-FLAG
                                                                    NIL
                                                                    :SPACES
                                                                    NIL
                                                                    :CRS
                                                                    NIL
                                                                    :FORMAT
                                                                    (LIST))
                                                           (MAKE-BP :VALUE
                                                                    0
                                                                    :UNITED-FLAG
                                                                    NIL
                                                                    :SPACES
                                                                    NIL
                                                                    :CRS
                                                                    NIL
                                                                    :FORMAT
                                                                    (LIST))))))
                                                    ((MAKE-BP :VALUE
                                                              0
                                                              :UNITED-FLAG
                                                              NIL
                                                              :SPACES
                                                              NIL
                                                              :CRS
                                                              NIL
                                                              :FORMAT
                                                              (LIST))
                                                      (MAKE-BP :VALUE
                                                               0
                                                               :UNITED-FLAG
                                                               NIL
                                                               :SPACES
                                                               NIL
                                                               :CRS
                                                               NIL
                                                               :FORMAT
                                                               (LIST))
                                                      (MAKE-BP :VALUE
                                                               0
                                                               :UNITED-FLAG
                                                               NIL
                                                               :SPACES
                                                               NIL
                                                               :CRS
                                                               NIL
                                                               :FORMAT
                                                               (LIST))
                                                      (MAKE-BP :VALUE
                                                               0
                                                               :UNITED-FLAG
                                                               NIL
                                                               :SPACES
                                                               NIL
                                                               :CRS
                                                               NIL
                                                               :FORMAT
                                                               (LIST))
                                                      (MAKE-BP :VALUE
                                                               0
                                                               :UNITED-FLAG
                                                               NIL
                                                               :SPACES
                                                               NIL
                                                               :CRS
                                                               NIL
                                                               :FORMAT
                                                               (LIST))
                                                      (MAKE-BP :VALUE
                                                               0
                                                               :UNITED-FLAG
                                                               NIL
                                                               :SPACES
                                                               NIL
                                                               :CRS
                                                               NIL
                                                               :FORMAT
                                                               (LIST))))))))))



(DEFUN PASCAL-UNP-FUNCTION-LIST-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4 V5 V6 V7)
         (SETF V0 AS)
         (NT-UNP 'PASCAL::FUNCTION-LIST
                 AS
                 ((UNP-BIND 'ALT_ V0)
                   (DIS-ALT V0
                            ((LAMBDA (X)
                                     (AND (DIS-OP 'PASCAL::PROC-DEF
                                                  X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::FUNCT-DEF
                                                   X)))))
                   (UNP-NAME 'NIL V1)
                   (UNP-ALT V0
                            (((PASCAL-UNP-FUNCTION-LIST-AUX-ALT-1 V0 V1))
                              ((PASCAL-UNP-FUNCTION-LIST-AUX-ALT-2 V0 V1))))))))



(DEFUN PASCAL-UNP-FUNCTION-LIST-AUX-ALT-1
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::PROC-DEF)
                                         (UNP-NAME 'ID V2)
                                         (DIS-OPT V3
                                                  (LAMBDA (X)
                                                          (AND
                                                            (DIS-OP
                                                              'PASCAL::PARAMS
                                                              X)
                                                            (NULL
                                                              (GET-TERM-ARGS X))))
                                                  (LAMBDA (X)
                                                          (AND
                                                            (DIS-OP
                                                              'PASCAL::PARAMS
                                                              X))))
                                         (UNP-OPT-AUG V3
                                                      ((UNP-ELIST-CONST))
                                                      ((UNP-LIST-CONST)
                                                        (UNP-NAME 'DOUBLEPLUS
                                                                  V4)))
                                         (UNP-NAME 'BLOCK V6)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::PROCEDURE))
                                             ((UNP-LT 'SBST::ID V2))
                                             ((UNP-OPT V3
                                                       ((UNP-SEQ
                                                          (((UNP-KEYWORD
                                                              'SBST::|(|))
                                                            ((UNP-UTERM V4
                                                                      ((UNP-DOUBLE-REPT
                                                                      V4
                                                                      ((UNP-UTERM
                                                                      V5
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-PARAMETER-TYPE
                                                                      V5))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|))
                                                                      V5
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                            ((UNP-KEYWORD
                                                               'SBST::|)|)))
                                                          ((MAKE-BP :VALUE
                                                                    0
                                                                    :UNITED-FLAG
                                                                    NIL
                                                                    :SPACES
                                                                    NIL
                                                                    :CRS
                                                                    NIL
                                                                    :FORMAT
                                                                    (LIST))
                                                            (MAKE-BP :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST))
                                                            (MAKE-BP :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST)))))))
                                             ((UNP-KEYWORD 'SBST::|;|))
                                             ((UNP-NT PASCAL-UNP-BLOCK
                                                      V6)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-FUNCTION-LIST-AUX-ALT-2
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::FUNCT-DEF)
                                         (UNP-NAME 'ID V2)
                                         (DIS-OPT V3
                                                  (LAMBDA (X)
                                                          (AND
                                                            (DIS-OP
                                                              'PASCAL::PARAMS
                                                              X)
                                                            (NULL
                                                              (GET-TERM-ARGS X))))
                                                  (LAMBDA (X)
                                                          (AND
                                                            (DIS-OP
                                                              'PASCAL::PARAMS
                                                              X))))
                                         (UNP-OPT-AUG V3
                                                      ((UNP-ELIST-CONST))
                                                      ((UNP-LIST-CONST)
                                                        (UNP-NAME 'DOUBLEPLUS
                                                                  V4)))
                                         (UNP-NAME 'ID V6)
                                         (UNP-NAME 'BLOCK V7)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::FUNCTION))
                                             ((UNP-LT 'SBST::ID V2))
                                             ((UNP-OPT V3
                                                       ((UNP-SEQ
                                                          (((UNP-KEYWORD
                                                              'SBST::|(|))
                                                            ((UNP-UTERM V4
                                                                      ((UNP-DOUBLE-REPT
                                                                      V4
                                                                      ((UNP-UTERM
                                                                      V5
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-PARAMETER-TYPE
                                                                      V5))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|))
                                                                      V5
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                            ((UNP-KEYWORD
                                                               'SBST::|)|)))
                                                          ((MAKE-BP :VALUE
                                                                    0
                                                                    :UNITED-FLAG
                                                                    NIL
                                                                    :SPACES
                                                                    NIL
                                                                    :CRS
                                                                    NIL
                                                                    :FORMAT
                                                                    (LIST))
                                                            (MAKE-BP :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST))
                                                            (MAKE-BP :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST)))))))
                                             ((UNP-KEYWORD 'SBST::|:|))
                                             ((UNP-LT 'SBST::ID V6))
                                             ((UNP-KEYWORD 'SBST::|;|))
                                             ((UNP-NT PASCAL-UNP-BLOCK
                                                      V7)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-HEADING-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3
             V4
             V5
             V6)
         (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4 V5 V6)
         (SETF V0 AS)
         (NT-UNP 'PASCAL::HEADING
                 AS
                 ((UNP-BIND 'ALT_ V0)
                   (DIS-ALT V0
                            ((LAMBDA (X)
                                     (AND (DIS-OP 'PASCAL::PROC-PARAM
                                                  X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::FUNCT-PARAM
                                                   X)))))
                   (UNP-NAME 'NIL V1)
                   (UNP-ALT V0
                            (((PASCAL-UNP-HEADING-AUX-ALT-1 V0 V1))
                              ((PASCAL-UNP-HEADING-AUX-ALT-2 V0 V1))))))))



(DEFUN PASCAL-UNP-HEADING-AUX-ALT-1
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::PROC-PARAM)
                                         (UNP-NAME 'ID V2)
                                         (DIS-OPT V3
                                                  (LAMBDA (X)
                                                          (AND
                                                            (DIS-OP
                                                              'PASCAL::PARAMS
                                                              X)
                                                            (NULL
                                                              (GET-TERM-ARGS X))))
                                                  (LAMBDA (X)
                                                          (AND
                                                            (DIS-OP
                                                              'PASCAL::PARAMS
                                                              X))))
                                         (UNP-OPT-AUG V3
                                                      ((UNP-ELIST-CONST))
                                                      ((UNP-LIST-CONST)
                                                        (UNP-NAME 'DOUBLEPLUS
                                                                  V4)))
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::PROCEDURE))
                                             ((UNP-LT 'SBST::ID V2))
                                             ((UNP-OPT V3
                                                       ((UNP-SEQ
                                                          (((UNP-KEYWORD
                                                              'SBST::|(|))
                                                            ((UNP-UTERM V4
                                                                      ((UNP-DOUBLE-REPT
                                                                      V4
                                                                      ((UNP-UTERM
                                                                      V5
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-PARAMETER-TYPE
                                                                      V5))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|))
                                                                      V5
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                            ((UNP-KEYWORD
                                                               'SBST::|)|)))
                                                          ((MAKE-BP :VALUE
                                                                    0
                                                                    :UNITED-FLAG
                                                                    NIL
                                                                    :SPACES
                                                                    NIL
                                                                    :CRS
                                                                    NIL
                                                                    :FORMAT
                                                                    (LIST))
                                                            (MAKE-BP :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST))
                                                            (MAKE-BP :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST))))))))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-HEADING-AUX-ALT-2
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::FUNCT-PARAM)
                                         (UNP-NAME 'ID V2)
                                         (DIS-OPT V3
                                                  (LAMBDA (X)
                                                          (AND
                                                            (DIS-OP
                                                              'PASCAL::PARAMS
                                                              X)
                                                            (NULL
                                                              (GET-TERM-ARGS X))))
                                                  (LAMBDA (X)
                                                          (AND
                                                            (DIS-OP
                                                              'PASCAL::PARAMS
                                                              X))))
                                         (UNP-OPT-AUG V3
                                                      ((UNP-ELIST-CONST))
                                                      ((UNP-LIST-CONST)
                                                        (UNP-NAME 'DOUBLEPLUS
                                                                  V4)))
                                         (UNP-NAME 'ID V6)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::FUNCTION))
                                             ((UNP-LT 'SBST::ID V2))
                                             ((UNP-OPT V3
                                                       ((UNP-SEQ
                                                          (((UNP-KEYWORD
                                                              'SBST::|(|))
                                                            ((UNP-UTERM V4
                                                                      ((UNP-DOUBLE-REPT
                                                                      V4
                                                                      ((UNP-UTERM
                                                                      V5
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-PARAMETER-TYPE
                                                                      V5))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|))
                                                                      V5
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                            ((UNP-KEYWORD
                                                               'SBST::|)|)))
                                                          ((MAKE-BP :VALUE
                                                                    0
                                                                    :UNITED-FLAG
                                                                    NIL
                                                                    :SPACES
                                                                    NIL
                                                                    :CRS
                                                                    NIL
                                                                    :FORMAT
                                                                    (LIST))
                                                            (MAKE-BP :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST))
                                                            (MAKE-BP :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST)))))))
                                             ((UNP-KEYWORD 'SBST::|:|))
                                             ((UNP-LT 'SBST::ID V6)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-PARAMETER-TYPE-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3
             V4
             V5)
         (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4 V5)
         (SETF V0 AS)
         (NT-UNP 'PASCAL::PARAMETER-TYPE
                 AS
                 ((UNP-BIND 'ALT_ V0)
                   (DIS-ALT V0
                            ((LAMBDA (X)
                                     (OR
                                       (AND (DIS-OP 'PASCAL::VAL X)
                                            (AND
                                              (DIS-OP 'PASCAL::IDS
                                                      (TERM-ARGN X 0))))
                                       (AND (DIS-OP 'REF X)
                                            (AND
                                              (DIS-OP 'PASCAL::IDS
                                                      (TERM-ARGN X 0))))))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::PROC-PARAM
                                                   X)))))
                   (UNP-NAME 'NIL V1)
                   (UNP-ALT V0
                            (((PASCAL-UNP-PARAMETER-TYPE-AUX-ALT-1 V0 V1))
                              ((PASCAL-UNP-PARAMETER-TYPE-AUX-ALT-2 V0 V1))))))))



(DEFUN PASCAL-UNP-PARAMETER-TYPE-AUX-ALT-1
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1)
                      (DIS-OPT V2
                               (LAMBDA (X)
                                       (AND (DIS-OP 'PASCAL::VAL X)
                                            (AND
                                              (DIS-OP 'PASCAL::IDS
                                                      (TERM-ARGN X 0)))))
                               (LAMBDA (X)
                                       (AND (DIS-OP 'REF X)
                                            (AND
                                              (DIS-OP 'PASCAL::IDS
                                                      (TERM-ARGN X 0))))))
                      (UNP-OPT-AUG V2
                                   ((UNP-TERM-CONST 'PASCAL::VAL)
                                     (UNP-LIST-CONST)
                                     (UNP-NAME 'DOUBLEPLUS V3)
                                     (UNP-NAME 'ID V5))
                                   ((UNP-TERM-CONST 'REF) (UNP-LIST-CONST)
                                                          (UNP-NAME 'DOUBLEPLUS
                                                                    V3)
                                                          (UNP-NAME 'ID V5)))
                      (UNP-SEQ
                        (((UNP-OPT V2
                                   ((UNP-KEYWORD 'SBST::VAR))))
                          ((UNP-UTERM V3
                                      ((UNP-DOUBLE-REPT V3
                                                        ((UNP-UTERM V4
                                                                    ((UNP-LT
                                                                      'SBST::ID
                                                                      V4))))
                                                        ((UNP-KEYWORD
                                                           'SBST::|,|))
                                                        V4
                                                        (MAKE-BP :VALUE
                                                                 2
                                                                 :UNITED-FLAG
                                                                 NIL
                                                                 :SPACES
                                                                 NIL
                                                                 :CRS
                                                                 NIL
                                                                 :FORMAT
                                                                 (LIST))
                                                        (MAKE-BP :VALUE
                                                                 0
                                                                 :UNITED-FLAG
                                                                 NIL
                                                                 :SPACES
                                                                 NIL
                                                                 :CRS
                                                                 NIL
                                                                 :FORMAT
                                                                 (LIST))))))
                          ((UNP-KEYWORD 'SBST::|:|))
                          ((UNP-LT 'SBST::ID V5)))
                        ((MAKE-BP :VALUE
                                  0
                                  :UNITED-FLAG
                                  NIL
                                  :SPACES
                                  NIL
                                  :CRS
                                  NIL
                                  :FORMAT
                                  (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))))))))



(DEFUN PASCAL-UNP-PARAMETER-TYPE-AUX-ALT-2
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5)
         (UNP-UTERM V1
                    ((UNP-BIND 'NONTERMINAL_ V1)
                      (UNP-TERM-CONST 'PASCAL::PROC-PARAM)
                      (UNP-NAME 'HEADING V1)
                      (UNP-NT PASCAL-UNP-HEADING V1)))))



(DEFUN PASCAL-UNP-MY-TYPE-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3
             V4
             V5)
         (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4 V5)
         (SETF V0 AS)
         (NT-UNP 'PASCAL::MY-TYPE
                 AS
                 ((UNP-BIND 'ALT_ V0)
                   (DIS-ALT V0
                            ((LAMBDA (X)
                                     (PASCAL-DIS-SIMPLE-TYPE X))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::POINTER
                                                   X)))
                              (LAMBDA (X)
                                      (OR (AND (DIS-OP 'SET X))
                                          (AND (DIS-OP 'PASCAL::PACKED-SET
                                                       X))))
                              (LAMBDA (X)
                                      (OR
                                        (AND (DIS-OP 'ARRAY X)
                                             (AND
                                               (DIS-OP 'PASCAL::SUBSCRIPTS
                                                       (TERM-ARGN X 0))))
                                        (AND (DIS-OP 'PASCAL::PACKED-ARRAY
                                                     X)
                                             (AND
                                               (DIS-OP 'PASCAL::SUBSCRIPTS
                                                       (TERM-ARGN X 0))))))
                              (LAMBDA (X)
                                      (OR (AND (DIS-OP 'PASCAL::RECORD
                                                       X))
                                          (AND
                                            (DIS-OP 'PASCAL::PACKED-RECORD
                                                    X))))
                              (LAMBDA (X)
                                      (OR (AND (DIS-OP 'PASCAL::FILE
                                                       X))
                                          (AND
                                            (DIS-OP 'PASCAL::PACKED-FILE
                                                    X))))))
                   (UNP-NAME 'NIL V1)
                   (UNP-ALT V0
                            (((PASCAL-UNP-MY-TYPE-AUX-ALT-1 V0 V1))
                              ((PASCAL-UNP-MY-TYPE-AUX-ALT-2 V0 V1))
                              ((PASCAL-UNP-MY-TYPE-AUX-ALT-3 V0 V1))
                              ((PASCAL-UNP-MY-TYPE-AUX-ALT-4 V0 V1))
                              ((PASCAL-UNP-MY-TYPE-AUX-ALT-5 V0 V1))
                              ((PASCAL-UNP-MY-TYPE-AUX-ALT-6 V0 V1))))))))



(DEFUN PASCAL-UNP-MY-TYPE-AUX-ALT-1
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5)
         (UNP-NT PASCAL-UNP-SIMPLE-TYPE V1)))



(DEFUN PASCAL-UNP-MY-TYPE-AUX-ALT-2
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::POINTER)
                                         (UNP-NAME 'ID V2)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::^))
                                             ((UNP-LT 'SBST::ID V2)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-MY-TYPE-AUX-ALT-3
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1)
                      (DIS-OPT V2
                               (LAMBDA (X)
                                       (AND (DIS-OP 'SET X)))
                               (LAMBDA (X)
                                       (AND (DIS-OP 'PASCAL::PACKED-SET
                                                    X))))
                      (UNP-OPT-AUG V2
                                   ((UNP-TERM-CONST 'SET)
                                     (UNP-NAME 'SIMPLE-TYPE V3))
                                   ((UNP-TERM-CONST 'PASCAL::PACKED-SET)
                                     (UNP-NAME 'SIMPLE-TYPE V3)))
                      (UNP-SEQ
                        (((UNP-OPT V2
                                   ((UNP-KEYWORD 'SBST::PACKED))))
                          ((UNP-KEYWORD 'SBST::SET))
                          ((UNP-KEYWORD 'SBST::OF))
                          ((UNP-NT PASCAL-UNP-SIMPLE-TYPE
                                   V3)))
                        ((MAKE-BP :VALUE
                                  0
                                  :UNITED-FLAG
                                  NIL
                                  :SPACES
                                  NIL
                                  :CRS
                                  NIL
                                  :FORMAT
                                  (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))))))))



(DEFUN PASCAL-UNP-MY-TYPE-AUX-ALT-4
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1)
                      (DIS-OPT V2
                               (LAMBDA (X)
                                       (AND (DIS-OP 'ARRAY X)
                                            (AND
                                              (DIS-OP 'PASCAL::SUBSCRIPTS
                                                      (TERM-ARGN X 0)))))
                               (LAMBDA (X)
                                       (AND (DIS-OP 'PASCAL::PACKED-ARRAY
                                                    X)
                                            (AND
                                              (DIS-OP 'PASCAL::SUBSCRIPTS
                                                      (TERM-ARGN X 0))))))
                      (UNP-OPT-AUG V2
                                   ((UNP-TERM-CONST 'ARRAY) (UNP-LIST-CONST)
                                                            (UNP-NAME
                                                              'DOUBLEPLUS
                                                              V3)
                                                            (UNP-NAME 'MY-TYPE
                                                                      V5))
                                   ((UNP-TERM-CONST 'PASCAL::PACKED-ARRAY)
                                     (UNP-LIST-CONST)
                                     (UNP-NAME 'DOUBLEPLUS V3)
                                     (UNP-NAME 'MY-TYPE V5)))
                      (UNP-SEQ
                        (((UNP-OPT V2
                                   ((UNP-KEYWORD 'SBST::PACKED))))
                          ((UNP-KEYWORD 'SBST::ARRAY))
                          ((UNP-KEYWORD 'SBST::[))
                          ((UNP-UTERM V3
                                      ((UNP-DOUBLE-REPT V3
                                                        ((UNP-UTERM V4
                                                                    ((UNP-NT
                                                                      PASCAL-UNP-SIMPLE-TYPE
                                                                      V4))))
                                                        ((UNP-KEYWORD
                                                           'SBST::|,|))
                                                        V4
                                                        (MAKE-BP :VALUE
                                                                 2
                                                                 :UNITED-FLAG
                                                                 NIL
                                                                 :SPACES
                                                                 NIL
                                                                 :CRS
                                                                 NIL
                                                                 :FORMAT
                                                                 (LIST))
                                                        (MAKE-BP :VALUE
                                                                 0
                                                                 :UNITED-FLAG
                                                                 NIL
                                                                 :SPACES
                                                                 NIL
                                                                 :CRS
                                                                 NIL
                                                                 :FORMAT
                                                                 (LIST))))))
                          ((UNP-KEYWORD 'SBST::]))
                          ((UNP-KEYWORD 'SBST::OF))
                          ((UNP-NT PASCAL-UNP-MY-TYPE V5)))
                        ((MAKE-BP :VALUE
                                  0
                                  :UNITED-FLAG
                                  NIL
                                  :SPACES
                                  NIL
                                  :CRS
                                  NIL
                                  :FORMAT
                                  (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))))))))



(DEFUN PASCAL-UNP-MY-TYPE-AUX-ALT-5
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1)
                      (DIS-OPT V2
                               (LAMBDA (X)
                                       (AND (DIS-OP 'PASCAL::RECORD
                                                    X)))
                               (LAMBDA (X)
                                       (AND (DIS-OP 'PASCAL::PACKED-RECORD
                                                    X))))
                      (UNP-OPT-AUG V2
                                   ((UNP-TERM-CONST 'PASCAL::RECORD)
                                     (UNP-NAME 'OPT V4))
                                   ((UNP-TERM-CONST 'PASCAL::PACKED-RECORD)
                                     (UNP-NAME 'OPT V4)))
                      (UNP-SEQ
                        (((UNP-OPT V2
                                   ((UNP-KEYWORD 'SBST::PACKED))))
                          ((UNP-KEYWORD 'SBST::RECORD))
                          ((UNP-BIND 'OPT_ V4)
                            (DIS-OPT V3
                                     (LAMBDA (X)
                                             (AND
                                               (DIS-OP 'PASCAL::MY-TYPE-NULL-1
                                                       X)))
                                     (LAMBDA (X)
                                             (AND (DIS-OP 'PASCAL::FLIST
                                                          X))))
                            (UNP-OPT-AUG V3
                                         ((UNP-NULL-CONST))
                                         ((UNP-NAME 'NIL V5)))
                            (UNP-OPT V3
                                     ((UNP-UTERM V5
                                                 ((UNP-BIND 'NONTERMINAL_
                                                            V5)
                                                   (UNP-TERM-CONST
                                                     'PASCAL::FLIST)
                                                   (UNP-NAME 'FIELD-LIST
                                                             V5)
                                                   (UNP-NT
                                                     PASCAL-UNP-FIELD-LIST
                                                     V5))))))
                          ((UNP-KEYWORD 'SBST::END)))
                        ((MAKE-BP :VALUE
                                  0
                                  :UNITED-FLAG
                                  NIL
                                  :SPACES
                                  NIL
                                  :CRS
                                  NIL
                                  :FORMAT
                                  (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))))))))



(DEFUN PASCAL-UNP-MY-TYPE-AUX-ALT-6
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1)
                      (DIS-OPT V2
                               (LAMBDA (X)
                                       (AND (DIS-OP 'PASCAL::FILE
                                                    X)))
                               (LAMBDA (X)
                                       (AND (DIS-OP 'PASCAL::PACKED-FILE
                                                    X))))
                      (UNP-OPT-AUG V2
                                   ((UNP-TERM-CONST 'PASCAL::FILE)
                                     (UNP-NAME 'MY-TYPE V3))
                                   ((UNP-TERM-CONST 'PASCAL::PACKED-FILE)
                                     (UNP-NAME 'MY-TYPE V3)))
                      (UNP-SEQ
                        (((UNP-OPT V2
                                   ((UNP-KEYWORD 'SBST::PACKED))))
                          ((UNP-KEYWORD 'SBST::FILE))
                          ((UNP-KEYWORD 'SBST::OF))
                          ((UNP-NT PASCAL-UNP-MY-TYPE V3)))
                        ((MAKE-BP :VALUE
                                  0
                                  :UNITED-FLAG
                                  NIL
                                  :SPACES
                                  NIL
                                  :CRS
                                  NIL
                                  :FORMAT
                                  (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))))))))



(DEFUN PASCAL-UNP-FIELD-LIST-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3
             V4
             V5
             V6
             V7
             V8
             V9
             V10
             V11
             V12
             V13
             V14
             V15
             V16
             V17
             V18
             V19
             V20
             V21)
         (ERGO-IGNORE-IF-UNUSED V0
                                V1
                                V2
                                V3
                                V4
                                V5
                                V6
                                V7
                                V8
                                V9
                                V10
                                V11
                                V12
                                V13
                                V14
                                V15
                                V16
                                V17
                                V18
                                V19
                                V20
                                V21)
         (SETF V0 AS)
         (NT-UNP 'PASCAL::FIELD-LIST
                 AS
                 ((UNP-BIND 'ALT_ V0)
                   (DIS-ALT V0
                            ((LAMBDA (X)
                                     (AND (DIS-OP 'PASCAL::FIELD-LIST
                                                  X)
                                          (AND
                                            (DIS-OP 'PASCAL::FIELDS
                                                    (TERM-ARGN X 0)))))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::VARIANT-PART
                                                   X)
                                           (AND
                                             (DIS-OP 'PASCAL::BRANCHES
                                                     (TERM-ARGN X 2)))))))
                   (UNP-NAME 'NIL V1)
                   (UNP-ALT V0
                            (((PASCAL-UNP-FIELD-LIST-AUX-ALT-1 V0 V1))
                              ((PASCAL-UNP-FIELD-LIST-AUX-ALT-2 V0 V1))))))))



(DEFUN PASCAL-UNP-FIELD-LIST-AUX-ALT-1
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7
             V8
             V9
             V10
             V11
             V12
             V13
             V14
             V15
             V16
             V17
             V18
             V19
             V20
             V21)
         (ERGO-IGNORE-IF-UNUSED V2
                                V3
                                V4
                                V5
                                V6
                                V7
                                V8
                                V9
                                V10
                                V11
                                V12
                                V13
                                V14
                                V15
                                V16
                                V17
                                V18
                                V19
                                V20
                                V21)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::FIELD-LIST)
                                         (UNP-LIST-CONST)
                                         (UNP-NAME 'PLUS V2)
                                         (UNP-NAME 'OPT V8)
                                         (UNP-SEQ
                                           (((UNP-UTERM V2
                                                        ((UNP-REPT V2
                                                                   ((UNP-UTERM
                                                                      V3
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V3)
                                                                      (UNP-TERM-CONST
                                                                      'PASCAL::FIELDS)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'DOUBLEPLUS
                                                                      V4)
                                                                      (UNP-NAME
                                                                      'MY-TYPE
                                                                      V6)
                                                                      (UNP-SEQ
                                                                      (((UNP-UTERM
                                                                      V4
                                                                      ((UNP-DOUBLE-REPT
                                                                      V4
                                                                      ((UNP-UTERM
                                                                      V5
                                                                      ((UNP-LT
                                                                      'SBST::ID
                                                                      V5))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|,|))
                                                                      V5
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|:|))
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-MY-TYPE
                                                                      V6))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                   V3
                                                                   (MAKE-BP
                                                                     :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST))))))
                                             ((UNP-BIND 'OPT_ V8)
                                               (DIS-OPT V7
                                                        (LAMBDA (X)
                                                                (AND
                                                                  (DIS-OP
                                                                    'PASCAL::FIELD-LIST-NULL-1
                                                                    X)))
                                                        (LAMBDA (X)
                                                                (AND
                                                                  (DIS-OP
                                                                    'PASCAL::VARIANT-PART
                                                                    X)
                                                                  (AND
                                                                    (DIS-OP
                                                                      'PASCAL::BRANCHES
                                                                      (TERM-ARGN
                                                                      X
                                                                      2))))))
                                               (UNP-OPT-AUG V7
                                                            ((UNP-NULL-CONST))
                                                            ((UNP-NAME 'NIL
                                                                      V9)))
                                               (UNP-OPT V7
                                                        ((UNP-UTERM V9
                                                                    ((UNP-BIND
                                                                      'SEQ_
                                                                      V9)
                                                                      (UNP-TERM-CONST
                                                                      'PASCAL::VARIANT-PART)
                                                                      (UNP-NAME
                                                                      'OPT
                                                                      V11)
                                                                      (UNP-NAME
                                                                      'ID
                                                                      V14)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'DOUBLEPLUS
                                                                      V15)
                                                                      (UNP-SEQ
                                                                      (((UNP-KEYWORD
                                                                      'SBST::CASE))
                                                                      ((UNP-BIND
                                                                      'OPT_1
                                                                      V11)
                                                                      (DIS-OPT
                                                                      V10
                                                                      (LAMBDA
                                                                      (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'PASCAL::FIELD-LIST-NULL-2
                                                                      X)))
                                                                      (LAMBDA
                                                                      (X)
                                                                      (DIS-LT
                                                                      'SBST::ID
                                                                      X)))
                                                                      (UNP-OPT-AUG
                                                                      V10
                                                                      ((UNP-NULL-CONST))
                                                                      ((UNP-NAME
                                                                      'NIL
                                                                      V12)))
                                                                      (UNP-OPT
                                                                      V10
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V12)
                                                                      (UNP-NAME
                                                                      'ID
                                                                      V13)
                                                                      (UNP-SEQ
                                                                      (((UNP-LT
                                                                      'SBST::ID
                                                                      V13))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|:|)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      ((UNP-LT
                                                                      'SBST::ID
                                                                      V14))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::OF))
                                                                      ((UNP-UTERM
                                                                      V15
                                                                      ((UNP-DOUBLE-REPT
                                                                      V15
                                                                      ((UNP-UTERM
                                                                      V16
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V16)
                                                                      (UNP-TERM-CONST
                                                                      'PASCAL::BRANCH)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'DOUBLEPLUS
                                                                      V17)
                                                                      (UNP-NAME
                                                                      'OPT
                                                                      V20)
                                                                      (UNP-SEQ
                                                                      (((UNP-UTERM
                                                                      V17
                                                                      ((UNP-DOUBLE-REPT
                                                                      V17
                                                                      ((UNP-UTERM
                                                                      V18
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-CONSTANT
                                                                      V18))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|,|))
                                                                      V18
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|:|))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|(|))
                                                                      ((UNP-BIND
                                                                      'OPT_
                                                                      V20)
                                                                      (DIS-OPT
                                                                      V19
                                                                      (LAMBDA
                                                                      (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'PASCAL::FIELD-LIST-NULL-3
                                                                      X)))
                                                                      (LAMBDA
                                                                      (X)
                                                                      (PASCAL-DIS-FIELD-LIST
                                                                      X)))
                                                                      (UNP-OPT-AUG
                                                                      V19
                                                                      ((UNP-NULL-CONST))
                                                                      ((UNP-NAME
                                                                      'NIL
                                                                      V21)))
                                                                      (UNP-OPT
                                                                      V19
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-FIELD-LIST
                                                                      V21))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|)|)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|))
                                                                      V16
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))))))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-FIELD-LIST-AUX-ALT-2
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7
             V8
             V9
             V10
             V11
             V12
             V13
             V14
             V15
             V16
             V17
             V18
             V19
             V20
             V21)
         (ERGO-IGNORE-IF-UNUSED V2
                                V3
                                V4
                                V5
                                V6
                                V7
                                V8
                                V9
                                V10
                                V11
                                V12
                                V13
                                V14
                                V15
                                V16
                                V17
                                V18
                                V19
                                V20
                                V21)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::VARIANT-PART)
                                         (UNP-NAME 'OPT V3)
                                         (UNP-NAME 'ID V6)
                                         (UNP-LIST-CONST)
                                         (UNP-NAME 'DOUBLEPLUS V7)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::CASE))
                                             ((UNP-BIND 'OPT_1 V3)
                                               (DIS-OPT V2
                                                        (LAMBDA (X)
                                                                (AND
                                                                  (DIS-OP
                                                                    'PASCAL::FIELD-LIST-NULL-4
                                                                    X)))
                                                        (LAMBDA (X)
                                                                (DIS-LT
                                                                  'SBST::ID
                                                                  X)))
                                               (UNP-OPT-AUG V2
                                                            ((UNP-NULL-CONST))
                                                            ((UNP-NAME 'NIL
                                                                      V4)))
                                               (UNP-OPT V2
                                                        ((UNP-BIND 'SEQ_
                                                                   V4)
                                                          (UNP-NAME 'ID V5)
                                                          (UNP-SEQ
                                                            (((UNP-LT 'SBST::ID
                                                                      V5))
                                                              ((UNP-KEYWORD
                                                                 'SBST::|:|)))
                                                            ((MAKE-BP :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                              (MAKE-BP :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                             ((UNP-LT 'SBST::ID V6))
                                             ((UNP-KEYWORD 'SBST::OF))
                                             ((UNP-UTERM V7
                                                         ((UNP-DOUBLE-REPT V7
                                                                      ((UNP-UTERM
                                                                      V8
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V8)
                                                                      (UNP-TERM-CONST
                                                                      'PASCAL::BRANCH)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'DOUBLEPLUS
                                                                      V9)
                                                                      (UNP-NAME
                                                                      'OPT
                                                                      V12)
                                                                      (UNP-SEQ
                                                                      (((UNP-UTERM
                                                                      V9
                                                                      ((UNP-DOUBLE-REPT
                                                                      V9
                                                                      ((UNP-UTERM
                                                                      V10
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-CONSTANT
                                                                      V10))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|,|))
                                                                      V10
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|:|))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|(|))
                                                                      ((UNP-BIND
                                                                      'OPT_
                                                                      V12)
                                                                      (DIS-OPT
                                                                      V11
                                                                      (LAMBDA
                                                                      (X)
                                                                      (AND
                                                                      (DIS-OP
                                                                      'PASCAL::FIELD-LIST-NULL-5
                                                                      X)))
                                                                      (LAMBDA
                                                                      (X)
                                                                      (PASCAL-DIS-FIELD-LIST
                                                                      X)))
                                                                      (UNP-OPT-AUG
                                                                      V11
                                                                      ((UNP-NULL-CONST))
                                                                      ((UNP-NAME
                                                                      'NIL
                                                                      V13)))
                                                                      (UNP-OPT
                                                                      V11
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-FIELD-LIST
                                                                      V13))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|)|)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|))
                                                                      V8
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-SIMPLE-TYPE-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3)
         (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3)
         (SETF V0 AS)
         (NT-UNP 'PASCAL::SIMPLE-TYPE
                 AS
                 ((UNP-BIND 'ALT_ V0)
                   (DIS-ALT V0
                            ((LAMBDA (X)
                                     (DIS-LT 'SBST::ID X))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::ENUMERATED-TYPE
                                                   X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::RANGE
                                                   X)))))
                   (UNP-NAME 'NIL V1)
                   (UNP-ALT V0
                            (((PASCAL-UNP-SIMPLE-TYPE-AUX-ALT-1 V0 V1))
                              ((PASCAL-UNP-SIMPLE-TYPE-AUX-ALT-2 V0 V1))
                              ((PASCAL-UNP-SIMPLE-TYPE-AUX-ALT-3 V0 V1))))))))



(DEFUN PASCAL-UNP-SIMPLE-TYPE-AUX-ALT-1
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3)
         (ERGO-IGNORE-IF-UNUSED V2 V3)
         (UNP-LT 'SBST::ID V1)))



(DEFUN PASCAL-UNP-SIMPLE-TYPE-AUX-ALT-2
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3)
         (ERGO-IGNORE-IF-UNUSED V2 V3)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-LIST-CONST)
                                         (UNP-NAME 'DOUBLEPLUS V2)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::|(|))
                                             ((UNP-UTERM V2
                                                         ((UNP-DOUBLE-REPT V2
                                                                      ((UNP-UTERM
                                                                      V3
                                                                      ((UNP-LT
                                                                      'SBST::ID
                                                                      V3))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|,|))
                                                                      V3
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                             ((UNP-KEYWORD 'SBST::|)|)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-SIMPLE-TYPE-AUX-ALT-3
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3)
         (ERGO-IGNORE-IF-UNUSED V2 V3)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::RANGE)
                                         (UNP-NAME 'CONSTANT V2)
                                         (UNP-NAME 'CONSTANT V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-CONSTANT
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::|..|))
                                             ((UNP-NT PASCAL-UNP-CONSTANT V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-STATEMENT-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3)
         (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3)
         (SETF V0 AS)
         (NT-UNP 'PASCAL::STATEMENT
                 AS
                 ((UNP-UTERM V0
                             ((UNP-BIND 'SEQ_ V0)
                               (DIS-OPT V1
                                        (LAMBDA (X)
                                                (PASCAL-DIS-REAL-STATEMENT X))
                                        (LAMBDA (X)
                                                (AND
                                                  (DIS-OP 'PASCAL::NUMBER-STAT
                                                          X))))
                               (UNP-OPT-AUG V1
                                            ((UNP-NAME 'REAL-STATEMENT
                                                       V3))
                                            ((UNP-TERM-CONST
                                               'PASCAL::NUMBER-STAT)
                                              (UNP-NAME 'NUMBER V2)
                                              (UNP-NAME 'REAL-STATEMENT
                                                        V3)))
                               (UNP-SEQ
                                 (((UNP-OPT V1
                                            ((UNP-SEQ
                                               (((UNP-LT 'SBST::NUMBER
                                                         V2))
                                                 ((UNP-KEYWORD 'SBST::|:|)))
                                               ((MAKE-BP :VALUE
                                                         0
                                                         :UNITED-FLAG
                                                         NIL
                                                         :SPACES
                                                         NIL
                                                         :CRS
                                                         NIL
                                                         :FORMAT
                                                         (LIST))
                                                 (MAKE-BP :VALUE
                                                          0
                                                          :UNITED-FLAG
                                                          NIL
                                                          :SPACES
                                                          NIL
                                                          :CRS
                                                          NIL
                                                          :FORMAT
                                                          (LIST)))))))
                                   ((UNP-NT PASCAL-UNP-REAL-STATEMENT
                                            V3)))
                                 ((MAKE-BP :VALUE
                                           0
                                           :UNITED-FLAG
                                           NIL
                                           :SPACES
                                           NIL
                                           :CRS
                                           NIL
                                           :FORMAT
                                           (LIST))
                                   (MAKE-BP :VALUE
                                            0
                                            :UNITED-FLAG
                                            NIL
                                            :SPACES
                                            NIL
                                            :CRS
                                            NIL
                                            :FORMAT
                                            (LIST))))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4 V5 V6 V7)
         (SETF V0 AS)
         (NT-UNP 'PASCAL::REAL-STATEMENT
                 AS
                 ((UNP-BIND 'ALT_ V0)
                   (DIS-ALT V0
                            ((LAMBDA (X)
                                     (AND (DIS-OP 'PASCAL::ASSIGN
                                                  X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::STATS
                                                   X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::PROC-CALL
                                                   X)))
                              (LAMBDA (X)
                                      (OR (AND (DIS-OP 'PASCAL::IF-THEN
                                                       X))
                                          (AND
                                            (DIS-OP 'PASCAL::IF-THEN-ELSE
                                                    X))))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::REPEAT
                                                   X)
                                           (AND
                                             (DIS-OP 'PASCAL::STATS
                                                     (TERM-ARGN X 0)))))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::WHILE
                                                   X)))
                              (LAMBDA (X)
                                      (OR (AND (DIS-OP 'PASCAL::FOR-TO
                                                       X))
                                          (AND (DIS-OP 'PASCAL::FOR-DOWNTO
                                                       X))))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'CASE X)
                                           (AND
                                             (DIS-OP 'PASCAL::CHOICES
                                                     (TERM-ARGN X 1)))))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::WITH X)
                                           (AND
                                             (DIS-OP 'PASCAL::VARS
                                                     (TERM-ARGN X 0)))))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::GOTO X)))))
                   (UNP-NAME 'NIL V1)
                   (UNP-ALT V0
                            (((PASCAL-UNP-REAL-STATEMENT-AUX-ALT-1 V0 V1))
                              ((PASCAL-UNP-REAL-STATEMENT-AUX-ALT-2 V0 V1))
                              ((PASCAL-UNP-REAL-STATEMENT-AUX-ALT-3 V0 V1))
                              ((PASCAL-UNP-REAL-STATEMENT-AUX-ALT-4 V0 V1))
                              ((PASCAL-UNP-REAL-STATEMENT-AUX-ALT-5 V0 V1))
                              ((PASCAL-UNP-REAL-STATEMENT-AUX-ALT-6 V0 V1))
                              ((PASCAL-UNP-REAL-STATEMENT-AUX-ALT-7 V0 V1))
                              ((PASCAL-UNP-REAL-STATEMENT-AUX-ALT-8 V0 V1))
                              ((PASCAL-UNP-REAL-STATEMENT-AUX-ALT-9 V0 V1))
                              ((PASCAL-UNP-REAL-STATEMENT-AUX-ALT-10 V0 V1))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX-ALT-1
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::ASSIGN)
                                         (UNP-NAME 'VARIABLE V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-VARIABLE
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::|:=|))
                                             ((UNP-NT PASCAL-UNP-EXP
                                                      V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX-ALT-2
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-LIST-CONST)
                                         (UNP-NAME 'DOUBLESTAR V2)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::BEGIN))
                                             ((UNP-UTERM V2
                                                         ((UNP-DOUBLE-REPT V2
                                                                      ((UNP-UTERM
                                                                      V3
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-STATEMENT
                                                                      V3))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|))
                                                                      V3
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                             ((UNP-KEYWORD 'SBST::END)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST
                                                       (MAKE-TOKEN :KIND
                                                                   :WHITESPACE
                                                                   :SUBKIND
                                                                   :INDENT
                                                                   :VALUE
                                                                   2)))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST UNINDENT-TOKEN))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX-ALT-3
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::PROC-CALL)
                                         (UNP-NAME 'ID V2)
                                         (DIS-OPT V3
                                                  (LAMBDA (X)
                                                          (AND
                                                            (DIS-OP
                                                              'PASCAL::EXPS
                                                              X)
                                                            (NULL
                                                              (GET-TERM-ARGS X))))
                                                  (LAMBDA (X)
                                                          (AND
                                                            (DIS-OP
                                                              'PASCAL::EXPS
                                                              X))))
                                         (UNP-OPT-AUG V3
                                                      ((UNP-ELIST-CONST))
                                                      ((UNP-LIST-CONST)
                                                        (UNP-NAME 'DOUBLEPLUS
                                                                  V4)))
                                         (UNP-SEQ
                                           (((UNP-LT 'SBST::ID V2))
                                             ((UNP-OPT V3
                                                       ((UNP-SEQ
                                                          (((UNP-KEYWORD
                                                              'SBST::|(|))
                                                            ((UNP-UTERM V4
                                                                      ((UNP-DOUBLE-REPT
                                                                      V4
                                                                      ((UNP-UTERM
                                                                      V5
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-EXP
                                                                      V5))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|,|))
                                                                      V5
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                            ((UNP-KEYWORD
                                                               'SBST::|)|)))
                                                          ((MAKE-BP :VALUE
                                                                    0
                                                                    :UNITED-FLAG
                                                                    NIL
                                                                    :SPACES
                                                                    NIL
                                                                    :CRS
                                                                    NIL
                                                                    :FORMAT
                                                                    (LIST))
                                                            (MAKE-BP :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST))
                                                            (MAKE-BP :VALUE
                                                                     0
                                                                     :UNITED-FLAG
                                                                     NIL
                                                                     :SPACES
                                                                     NIL
                                                                     :CRS
                                                                     NIL
                                                                     :FORMAT
                                                                     (LIST))))))))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX-ALT-4
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1)
                      (DIS-OPT V4
                               (LAMBDA (X)
                                       (AND (DIS-OP 'PASCAL::IF-THEN
                                                    X)))
                               (LAMBDA (X)
                                       (AND (DIS-OP 'PASCAL::IF-THEN-ELSE
                                                    X))))
                      (UNP-OPT-AUG V4
                                   ((UNP-TERM-CONST 'PASCAL::IF-THEN)
                                     (UNP-NAME 'EXP V2)
                                     (UNP-NAME 'STATEMENT V3))
                                   ((UNP-TERM-CONST 'PASCAL::IF-THEN-ELSE)
                                     (UNP-NAME 'EXP V2)
                                     (UNP-NAME 'STATEMENT V3)
                                     (UNP-NAME 'STATEMENT V5)))
                      (UNP-SEQ
                        (((UNP-KEYWORD 'SBST::IF))
                          ((UNP-NT PASCAL-UNP-EXP V2))
                          ((UNP-KEYWORD 'SBST::THEN))
                          ((UNP-NT PASCAL-UNP-STATEMENT V3))
                          ((UNP-OPT V4
                                    ((UNP-SEQ
                                       (((UNP-KEYWORD 'SBST::ELSE))
                                         ((UNP-NT PASCAL-UNP-STATEMENT V5)))
                                       ((MAKE-BP :VALUE
                                                 0
                                                 :UNITED-FLAG
                                                 NIL
                                                 :SPACES
                                                 NIL
                                                 :CRS
                                                 NIL
                                                 :FORMAT
                                                 (LIST))
                                         (MAKE-BP :VALUE
                                                  0
                                                  :UNITED-FLAG
                                                  NIL
                                                  :SPACES
                                                  NIL
                                                  :CRS
                                                  NIL
                                                  :FORMAT
                                                  (LIST))))))))
                        ((MAKE-BP :VALUE
                                  0
                                  :UNITED-FLAG
                                  NIL
                                  :SPACES
                                  NIL
                                  :CRS
                                  NIL
                                  :FORMAT
                                  (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX-ALT-5
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::REPEAT)
                                         (UNP-LIST-CONST)
                                         (UNP-NAME 'DOUBLESTAR V2)
                                         (UNP-NAME 'EXP V4)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::REPEAT))
                                             ((UNP-UTERM V2
                                                         ((UNP-DOUBLE-REPT V2
                                                                      ((UNP-UTERM
                                                                      V3
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-STATEMENT
                                                                      V3))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|))
                                                                      V3
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                             ((UNP-KEYWORD 'SBST::UNTIL))
                                             ((UNP-NT PASCAL-UNP-EXP
                                                      V4)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST
                                                       (MAKE-TOKEN :KIND
                                                                   :WHITESPACE
                                                                   :SUBKIND
                                                                   :INDENT
                                                                   :VALUE
                                                                   2)))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST UNINDENT-TOKEN))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX-ALT-6
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::WHILE)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'STATEMENT V3)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::WHILE))
                                             ((UNP-NT PASCAL-UNP-EXP
                                                      V2))
                                             ((UNP-KEYWORD 'SBST::DO))
                                             ((UNP-NT PASCAL-UNP-STATEMENT
                                                      V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX-ALT-7
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1)
                      (DIS-ALT V4
                               ((LAMBDA (X)
                                        (AND (DIS-OP 'PASCAL::FOR-TO
                                                     X)))
                                 (LAMBDA (X)
                                         (AND (DIS-OP 'PASCAL::FOR-DOWNTO
                                                      X)))))
                      (UNP-ALT-AUG V4
                                   (((UNP-TERM-CONST 'PASCAL::FOR-TO)
                                      (UNP-NAME 'ID V2)
                                      (UNP-NAME 'EXP V3)
                                      (UNP-NAME 'EXP V5)
                                      (UNP-NAME 'STATEMENT V6))
                                     ((UNP-TERM-CONST 'PASCAL::FOR-DOWNTO)
                                       (UNP-NAME 'ID V2)
                                       (UNP-NAME 'EXP V3)
                                       (UNP-NAME 'EXP V5)
                                       (UNP-NAME 'STATEMENT V6))))
                      (UNP-SEQ
                        (((UNP-KEYWORD 'SBST::FOR)) ((UNP-LT 'SBST::ID
                                                             V2))
                                                    ((UNP-KEYWORD 'SBST::|:=|))
                                                    ((UNP-NT PASCAL-UNP-EXP
                                                             V3))
                                                    ((UNP-ALT V4
                                                              (((UNP-KEYWORD
                                                                  'SBST::TO))
                                                                ((UNP-KEYWORD
                                                                   'SBST::DOWNTO)))))
                                                    ((UNP-NT PASCAL-UNP-EXP V5))
                                                    ((UNP-KEYWORD 'SBST::DO))
                                                    ((UNP-NT
                                                       PASCAL-UNP-STATEMENT
                                                       V6)))
                        ((MAKE-BP :VALUE
                                  0
                                  :UNITED-FLAG
                                  NIL
                                  :SPACES
                                  NIL
                                  :CRS
                                  NIL
                                  :FORMAT
                                  (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX-ALT-8
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'CASE)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-LIST-CONST)
                                         (UNP-NAME 'DOUBLESTAR V3)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::CASE))
                                             ((UNP-NT PASCAL-UNP-EXP
                                                      V2))
                                             ((UNP-KEYWORD 'SBST::OF))
                                             ((UNP-UTERM V3
                                                         ((UNP-DOUBLE-REPT V3
                                                                      ((UNP-UTERM
                                                                      V4
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V4)
                                                                      (UNP-TERM-CONST
                                                                      'PASCAL::CASE-ENTRY)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'DOUBLEPLUS
                                                                      V5)
                                                                      (UNP-NAME
                                                                      'STATEMENT
                                                                      V7)
                                                                      (UNP-SEQ
                                                                      (((UNP-UTERM
                                                                      V5
                                                                      ((UNP-DOUBLE-REPT
                                                                      V5
                                                                      ((UNP-UTERM
                                                                      V6
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-CONSTANT
                                                                      V6))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|,|))
                                                                      V6
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-STATEMENT
                                                                      V7)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|;|))
                                                                      V4
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                             ((UNP-KEYWORD 'SBST::END)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX-ALT-9
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::WITH)
                                         (UNP-LIST-CONST)
                                         (UNP-NAME 'DOUBLEPLUS V2)
                                         (UNP-NAME 'STATEMENT V4)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::WITH))
                                             ((UNP-UTERM V2
                                                         ((UNP-DOUBLE-REPT V2
                                                                      ((UNP-UTERM
                                                                      V3
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-VARIABLE
                                                                      V3))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|,|))
                                                                      V3
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                             ((UNP-KEYWORD 'SBST::DO))
                                             ((UNP-NT PASCAL-UNP-STATEMENT
                                                      V4)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-REAL-STATEMENT-AUX-ALT-10
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4
             V5
             V6
             V7)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4 V5 V6 V7)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::GOTO)
                                         (UNP-NAME 'NUMBER V2)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::GOTO))
                                             ((UNP-LT 'SBST::NUMBER
                                                      V2)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4)
         (SETF V0 AS)
         (NT-UNP 'EXP
                 AS
                 ((UNP-BIND 'ALT_ V0)
                   (DIS-ALT V0
                            ((LAMBDA (X)
                                     (PASCAL-DIS-VARIABLE X))
                              (LAMBDA (X)
                                      (DIS-LT 'SBST::NUMBER X))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::LE X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::LT X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'EQ X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::GT X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::GE X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::NE X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::IN X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::PLUS X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::MINUS
                                                   X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'OR X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'AND X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::TIMES
                                                   X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'MOD X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::DIV X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::UNI-MINUS
                                                   X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::UNI-PLUS
                                                   X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'NOT X)))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'PASCAL::FUNCTION-CALL
                                                   X)
                                           (AND
                                             (DIS-OP 'PASCAL::EXPS
                                                     (TERM-ARGN X 1)))))))
                   (UNP-NAME 'NIL V1)
                   (UNP-ALT V0
                            (((PASCAL-UNP-EXP-AUX-ALT-1 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-2 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-3 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-4 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-5 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-6 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-7 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-8 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-9 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-10 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-11 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-12 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-13 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-14 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-15 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-16 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-17 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-18 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-19 V0 V1))
                              ((PASCAL-UNP-EXP-AUX-ALT-20 V0 V1))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-1
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-NT PASCAL-UNP-VARIABLE V1)))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-2
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-LT 'SBST::NUMBER V1)))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-3
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::LE)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::<=))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-4
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::LT)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::<))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-5
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'EQ)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::=))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-6
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::GT)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::>))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-7
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::GE)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::>=))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-8
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::NE)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::<>))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-9
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::IN)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::IN))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-10
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::PLUS)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::+))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-11
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::MINUS)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::-))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-12
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'OR)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::OR))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-13
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'AND)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::AND))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-14
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::TIMES)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::*))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-15
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'MOD)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::MOD))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-16
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::DIV)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-NAME 'EXP V3)
                                         (UNP-SEQ
                                           (((UNP-NT PASCAL-UNP-EXP
                                                     V2))
                                             ((UNP-KEYWORD 'SBST::DIV))
                                             ((UNP-NT PASCAL-UNP-EXP V3)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-17
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::UNI-MINUS)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::-))
                                             ((UNP-NT PASCAL-UNP-EXP
                                                      V2)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-18
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'PASCAL::UNI-PLUS)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::+))
                                             ((UNP-NT PASCAL-UNP-EXP
                                                      V2)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-19
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1) (UNP-TERM-CONST 'NOT)
                                         (UNP-NAME 'EXP V2)
                                         (UNP-SEQ
                                           (((UNP-KEYWORD 'SBST::NOT))
                                             ((UNP-NT PASCAL-UNP-EXP
                                                      V2)))
                                           ((MAKE-BP :VALUE
                                                     0
                                                     :UNITED-FLAG
                                                     NIL
                                                     :SPACES
                                                     NIL
                                                     :CRS
                                                     NIL
                                                     :FORMAT
                                                     (LIST))
                                             (MAKE-BP :VALUE
                                                      0
                                                      :UNITED-FLAG
                                                      NIL
                                                      :SPACES
                                                      NIL
                                                      :CRS
                                                      NIL
                                                      :FORMAT
                                                      (LIST))))))))



(DEFUN PASCAL-UNP-EXP-AUX-ALT-20
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET (V2
             V3
             V4)
         (ERGO-IGNORE-IF-UNUSED V2 V3 V4)
         (UNP-UTERM V1
                    ((UNP-BIND 'SEQ_ V1)
                      (UNP-TERM-CONST 'PASCAL::FUNCTION-CALL)
                      (UNP-NAME 'ID V2)
                      (UNP-LIST-CONST)
                      (UNP-NAME 'DOUBLEPLUS V3)
                      (UNP-SEQ
                        (((UNP-LT 'SBST::ID V2)) ((UNP-KEYWORD 'SBST::|(|))
                                                 ((UNP-UTERM V3
                                                             ((UNP-DOUBLE-REPT
                                                                V3
                                                                ((UNP-UTERM V4
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-EXP
                                                                      V4))))
                                                                ((UNP-KEYWORD
                                                                   'SBST::|,|))
                                                                V4
                                                                (MAKE-BP :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                (MAKE-BP :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                 ((UNP-KEYWORD 'SBST::|)|)))
                        ((MAKE-BP :VALUE
                                  0
                                  :UNITED-FLAG
                                  NIL
                                  :SPACES
                                  NIL
                                  :CRS
                                  NIL
                                  :FORMAT
                                  (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))
                          (MAKE-BP :VALUE
                                   0
                                   :UNITED-FLAG
                                   NIL
                                   :SPACES
                                   NIL
                                   :CRS
                                   NIL
                                   :FORMAT
                                   (LIST))))))))



(DEFUN PASCAL-UNP-VARIABLE-AUX
       (AS)
       (LET (V0
             V1
             V2
             V3
             V4
             V5
             V6
             V7
             V8)
         (ERGO-IGNORE-IF-UNUSED V0 V1 V2 V3 V4 V5 V6 V7 V8)
         (SETF V0 AS)
         (NT-UNP 'VARIABLE
                 AS
                 ((UNP-UTERM V0
                             ((UNP-BIND 'SEQ_ V0)
                               (DIS-OPT V2
                                        (LAMBDA (X)
                                                (DIS-LT 'SBST::ID X))
                                        (LAMBDA (X)
                                                (AND
                                                  (DIS-OP 'PASCAL::COMPLEX-REF
                                                          X))))
                               (UNP-OPT-AUG V2
                                            ((UNP-NAME 'ID V1))
                                            ((UNP-TERM-CONST
                                               'PASCAL::COMPLEX-REF)
                                              (UNP-NAME 'ID V1)
                                              (UNP-NAME 'OPT V3)))
                               (UNP-SEQ
                                 (((UNP-LT 'SBST::ID V1))
                                   ((UNP-BIND 'OPT_ V3)
                                     (UNP-OPT-AUG V2
                                                  ((UNP-NULL-CONST))
                                                  ((UNP-NAME 'NIL V5)))
                                     (UNP-OPT V2
                                              ((UNP-BIND 'ALT_ V5)
                                                (DIS-ALT V4
                                                         ((LAMBDA (X)
                                                                  (AND
                                                                    (DIS-OP
                                                                      'PASCAL::ARRAY-REF
                                                                      X)))
                                                           (LAMBDA (X)
                                                                   (AND
                                                                     (DIS-OP
                                                                      'PASCAL::REC-FIELD
                                                                      X)))
                                                           (LAMBDA (X)
                                                                   (AND
                                                                     (DIS-OP
                                                                      'PASCAL::POINTER-REF
                                                                      X)))))
                                                (UNP-ALT-AUG V4
                                                             (((UNP-NAME 'NIL
                                                                      V6))
                                                               ((UNP-NAME 'NIL
                                                                      V6))
                                                               ((UNP-NAME 'NIL
                                                                      V6))))
                                                (UNP-ALT V4
                                                         (((UNP-UTERM V6
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V6)
                                                                      (UNP-LIST-CONST)
                                                                      (UNP-NAME
                                                                      'DOUBLEPLUS
                                                                      V7)
                                                                      (UNP-SEQ
                                                                      (((UNP-KEYWORD
                                                                      'SBST::[))
                                                                      ((UNP-UTERM
                                                                      V7
                                                                      ((UNP-DOUBLE-REPT
                                                                      V7
                                                                      ((UNP-UTERM
                                                                      V8
                                                                      ((UNP-NT
                                                                      PASCAL-UNP-EXP
                                                                      V8))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::|,|))
                                                                      V8
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      2
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))))))
                                                                      ((UNP-KEYWORD
                                                                      'SBST::])))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                           ((UNP-UTERM V6
                                                                      ((UNP-BIND
                                                                      'SEQ_
                                                                      V6)
                                                                      (UNP-TERM-CONST
                                                                      'PASCAL::REC-FIELD)
                                                                      (UNP-NAME
                                                                      'ID
                                                                      V7)
                                                                      (UNP-SEQ
                                                                      (((UNP-KEYWORD
                                                                      'SBST::|.|))
                                                                      ((UNP-LT
                                                                      'SBST::ID
                                                                      V7)))
                                                                      ((MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST))
                                                                      (MAKE-BP
                                                                      :VALUE
                                                                      0
                                                                      :UNITED-FLAG
                                                                      NIL
                                                                      :SPACES
                                                                      NIL
                                                                      :CRS
                                                                      NIL
                                                                      :FORMAT
                                                                      (LIST)))))))
                                                           ((UNP-UTERM V6
                                                                      ((UNP-BIND
                                                                      'UKEYWORD_
                                                                      V6)
                                                                      (UNP-TERM-CONST
                                                                      'PASCAL::POINTER-REF)
                                                                      (UNP-KEYWORD
                                                                      'SBST::^))))))))))
                                 ((MAKE-BP :VALUE
                                           0
                                           :UNITED-FLAG
                                           NIL
                                           :SPACES
                                           NIL
                                           :CRS
                                           NIL
                                           :FORMAT
                                           (LIST))
                                   (MAKE-BP :VALUE
                                            0
                                            :UNITED-FLAG
                                            NIL
                                            :SPACES
                                            NIL
                                            :CRS
                                            NIL
                                            :FORMAT
                                            (LIST))))))))))



(DEFUN PASCAL-UNP-CONSTANT-AUX
       (AS)
       (LET (V0
             V1)
         (ERGO-IGNORE-IF-UNUSED V0 V1)
         (SETF V0 AS)
         (NT-UNP 'PASCAL::CONSTANT
                 AS
                 ((UNP-BIND 'ALT_ V0)
                   (DIS-ALT V0
                            ((LAMBDA (X)
                                     (DIS-LT 'SBST::NUMBER X))
                              (LAMBDA (X)
                                      (DIS-LT 'SBST::ID X))
                              (LAMBDA (X)
                                      (DIS-LT 'SBST::STRING X))
                              (LAMBDA (X)
                                      (AND (DIS-OP 'NULL X)))))
                   (UNP-NAME 'NIL V1)
                   (UNP-ALT V0
                            (((PASCAL-UNP-CONSTANT-AUX-ALT-1 V0 V1))
                              ((PASCAL-UNP-CONSTANT-AUX-ALT-2 V0 V1))
                              ((PASCAL-UNP-CONSTANT-AUX-ALT-3 V0 V1))
                              ((PASCAL-UNP-CONSTANT-AUX-ALT-4 V0 V1))))))))



(DEFUN PASCAL-UNP-CONSTANT-AUX-ALT-1
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET NIL
         (ERGO-IGNORE-IF-UNUSED)
         (UNP-LT 'SBST::NUMBER V1)))



(DEFUN PASCAL-UNP-CONSTANT-AUX-ALT-2
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET NIL
         (ERGO-IGNORE-IF-UNUSED)
         (UNP-LT 'SBST::ID V1)))



(DEFUN PASCAL-UNP-CONSTANT-AUX-ALT-3
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET NIL
         (ERGO-IGNORE-IF-UNUSED)
         (UNP-LT 'SBST::STRING V1)))



(DEFUN PASCAL-UNP-CONSTANT-AUX-ALT-4
       (V0 V1)
       (ERGO-IGNORE-IF-UNUSED V0 V1)
       (LET NIL
         (ERGO-IGNORE-IF-UNUSED)
         (UNP-UTERM V1
                    ((UNP-BIND 'UKEYWORD_ V1) (UNP-TERM-CONST 'NULL)
                                              (UNP-KEYWORD 'SBST::NULL)))))



(DEFUN PASCAL-DIS-PROGRAM
       (AS)
       (OR (IS-NT-OPSIG? 'PASCAL::PROGRAM AS)
           ((LAMBDA (X)
                    (DIS-OP 'PASCAL::PROGRAM X))
             AS)))



(DEFUN PASCAL-DIS-BLOCK
       (AS)
       (OR (IS-NT-OPSIG? 'BLOCK AS)
           ((LAMBDA (X) (DIS-OP 'BLOCK X)) AS)))



(DEFUN PASCAL-DIS-FUNCTION-LIST
       (AS)
       (OR (IS-NT-OPSIG? 'PASCAL::FUNCTION-LIST AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::FUNCT-DEF X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::PROC-DEF X))
                          X)))
             AS)))



(DEFUN PASCAL-DIS-HEADING
       (AS)
       (OR (IS-NT-OPSIG? 'PASCAL::HEADING AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::FUNCT-PARAM
                                         X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::PROC-PARAM
                                         X))
                          X)))
             AS)))



(DEFUN PASCAL-DIS-PARAMETER-TYPE
       (AS)
       (OR (IS-NT-OPSIG? 'PASCAL::PARAMETER-TYPE AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::PROC-PARAM
                                         X))
                          X)
                        ((LAMBDA (X) (DIS-OP 'REF X)) X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::VAL X))
                          X)))
             AS)))



(DEFUN PASCAL-DIS-MY-TYPE
       (AS)
       (OR (IS-NT-OPSIG? 'PASCAL::MY-TYPE AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::PACKED-FILE
                                         X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::FILE X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::PACKED-RECORD
                                         X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::RECORD X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::PACKED-ARRAY
                                         X))
                          X)
                        ((LAMBDA (X) (DIS-OP 'ARRAY X)) X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::PACKED-SET
                                         X))
                          X)
                        ((LAMBDA (X) (DIS-OP 'SET X)) X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::POINTER X))
                          X)
                        (PASCAL-DIS-SIMPLE-TYPE X)))
             AS)))



(DEFUN PASCAL-DIS-FIELD-LIST
       (AS)
       (OR (IS-NT-OPSIG? 'PASCAL::FIELD-LIST AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::VARIANT-PART
                                         X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::FIELD-LIST
                                         X))
                          X)))
             AS)))



(DEFUN PASCAL-DIS-SIMPLE-TYPE
       (AS)
       (OR (IS-NT-OPSIG? 'PASCAL::SIMPLE-TYPE AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::RANGE X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::ENUMERATED-TYPE
                                         X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-LT 'SBST::ID X))
                          X)))
             AS)))



(DEFUN PASCAL-DIS-STATEMENT
       (AS)
       (OR (IS-NT-OPSIG? 'PASCAL::STATEMENT AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::NUMBER-STAT
                                         X))
                          X)
                        (PASCAL-DIS-REAL-STATEMENT X)))
             AS)))



(DEFUN PASCAL-DIS-REAL-STATEMENT
       (AS)
       (OR (IS-NT-OPSIG? 'PASCAL::REAL-STATEMENT AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::GOTO X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::WITH X))
                          X)
                        ((LAMBDA (X) (DIS-OP 'CASE X)) X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::FOR-DOWNTO
                                         X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::FOR-TO X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::WHILE X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::REPEAT X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::IF-THEN-ELSE
                                         X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::IF-THEN X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::PROC-CALL X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::STATS X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::ASSIGN X))
                          X)))
             AS)))



(DEFUN PASCAL-DIS-EXP
       (AS)
       (OR (IS-NT-OPSIG? 'EXP AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::FUNCTION-CALL
                                         X))
                          X)
                        ((LAMBDA (X) (DIS-OP 'NOT X)) X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::UNI-PLUS X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::UNI-MINUS X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::DIV X))
                          X)
                        ((LAMBDA (X) (DIS-OP 'MOD X)) X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::TIMES X))
                          X)
                        ((LAMBDA (X) (DIS-OP 'AND X)) X)
                        ((LAMBDA (X) (DIS-OP 'OR X)) X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::MINUS X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::PLUS X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::IN X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::NE X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::GE X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::GT X))
                          X)
                        ((LAMBDA (X) (DIS-OP 'EQ X)) X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::LT X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::LE X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-LT 'SBST::NUMBER X))
                          X)
                        (PASCAL-DIS-VARIABLE X)))
             AS)))



(DEFUN PASCAL-DIS-VARIABLE
       (AS)
       (OR (IS-NT-OPSIG? 'VARIABLE AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X)
                                 (DIS-OP 'PASCAL::COMPLEX-REF
                                         X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-LT 'SBST::ID X))
                          X)))
             AS)))



(DEFUN PASCAL-DIS-CONSTANT
       (AS)
       (OR (IS-NT-OPSIG? 'PASCAL::CONSTANT AS)
           ((LAMBDA (X)
                    (OR ((LAMBDA (X) (DIS-OP 'NULL X)) X)
                        ((LAMBDA (X)
                                 (DIS-LT 'SBST::STRING X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-LT 'SBST::ID X))
                          X)
                        ((LAMBDA (X)
                                 (DIS-LT 'SBST::NUMBER X))
                          X)))
             AS)))

